@@ -600,6 +600,7 @@ METHOD knh_KLRCode_exec(Ctx *ctx, knh_sfp_t *sfp)
 		f.write('''
 	%s:; {
 		const %s *op = (%s*)pc;
+		//DBG2_P("%%p sfp[1]=%%d", pc, (int)sfp[1].ivalue);
 		DBG2_OPDUMP(ctx, pc);
 		%s;
 		pc += %s;
@@ -613,24 +614,70 @@ METHOD knh_KLRCode_exec(Ctx *ctx, knh_sfp_t *sfp)
 
 ''')
 
-def getparam(kc):
-	m = 'KLR_%s(ctx' % kc.name
+def getparam(kc, p):
+	m = 'JIT_%s(ctx' % kc.name
 	c = 1
 	for a in kc.tokens[1:]:
 		if a == 'addr':
-			m += ', NPC, JUMP'
+			if p == c :
+				m += ', NPC, JUMP1'
+			else:
+				m += ', NPC, JUMP0'
 		elif a == 'sfx':
-			d = 'const knh_sfx_t x%d = {%d00, %d00};\n\t\t' % (c, c, c + 1)
-			m = d + m + ', x%d' % (c)
+			if p == c:
+				m += ', (%d)' % (c)
+			else:
+				m += ', (-1)'
 			c += 1
+			if p == c:
+				m += ', (%d)' % (c)
+			else:
+				m += ', (-1)'
 		elif a == 'OBJ':
-			m += ', (Object*)%d00' % (c)
+			if p == c:
+				m += ', ((Object*)%d)' % (c)
+			else:
+				m += ', ((Object*)-1)'
 		else:
-			m += ', %d00' % (c)
+			if p == c:
+				m += ', (%d)' % (c)
+			else:
+				m += ', (-1)'
 		c += 1
 	m += ')'
 	return m
 
+def getpsize(kc):
+	c = 1
+	for a in kc.tokens[1:]:
+		if a == 'sfx':
+			c += 2
+		else:
+			c += 1
+	return c
+	
+def write_ftemp(f, kc, c):
+	f.write('''
+static
+METHOD jc%d_%s(Ctx *ctx, knh_sfp_t *sfp)
+{
+	__asm__ __volatile__("int3");
+	%s;
+	__asm__ __volatile__("int3");
+}
+
+''' % (c, kc.NAME, getparam(kc, c)))
+	
+def write_flist(f, kc):
+	m = '\t{jc0_%s' % kc.NAME
+	c = 1
+	psize = getpsize(kc)
+	while c < psize:
+		m += ',jc%d_%s' % (c, kc.NAME)
+		c += 1
+	m += '},\n'
+	f.write(m)
+	
 def write_template(f):
 
 	write_line(f)
@@ -641,44 +688,34 @@ def write_template(f):
 #undef _HERE_ 
 #endif
 #define _HERE_ NULL, 0
-#define JUMP *(0xdeadbeef)
-	
-static const char *pc = NULL;
+#define JUMP0 *(0xffffffff)
+#define JUMP1 *(0x00000001)
+//static volatile knh_sfp_t *reset_ifneed = NULL;	
 ''')
-#	f.write('''
-#METHOD codetemplate(Ctx *ctx, knh_sfp_t *sfp)
-#{
-#	static void *OPJUMP[] = {''')
-#	for kc in KCODE_LIST:
-#		f.write('''
-#		&&%s,''' % kc.OPLABEL)
-#	f.write('''
-#	};
-#	
-#''')
-#	for kc in KCODE_LIST:
-#		f.write('''
-#	%s:; {
-#		%s;
-#	}
-#''' % (kc.OPLABEL, getparam(kc)))
-#
-#	f.write('''
-#}
-##endif
-#
-#''')
-	
+	fmax = 0
+	pmax = 0
 	for kc in KCODE_LIST[:-2]:
-		f.write('''
-METHOD code_%s(Ctx *ctx, knh_sfp_t *sfp)
-{
-	%s;
-}
-
-''' % (kc.NAME, getparam(kc)))
+		fmax += 1
+		c = 0
+		psize = getpsize(kc)
+		while c < psize:
+			write_ftemp(f, kc, c)
+			c += 1
+		if pmax < psize: pmax = psize
 	
 	f.write('''
+static knh_fmethod codeTempList[%d][%d] = {
+''' % (fmax, pmax))
+	for kc in KCODE_LIST[:-2]:
+		write_flist(f, kc)
+	f.write('''
+};
+
+knh_fmethod konoha_getCodeTemplate(int opcode, int pos)
+{
+	return codeTempList[opcode][pos];
+}
+
 #endif/*KONOHA_CODETEMPLATE*/
 ''')
 
