@@ -701,7 +701,7 @@ def read_source(dir, data):
 		if fn.endswith('.h') and dir.find('/include/konoha') == -1: 
 			read_source_h(fpath, data)
 
-def read_xpackage(dir, data):
+def read_xpackage_OLD(dir, data):
 	fl = os.listdir(dir)
 	for fn in fl:
 		if fn.startswith('.'): continue
@@ -711,6 +711,8 @@ def read_xpackage(dir, data):
 		f = 'knh%s_load' % fn
 		data.STATICLIB_MAP[f] = f
 	
+def read_xpackage(dir, data):
+	pass
 
 #############
 
