@@ -77,13 +77,12 @@ typedef struct knh_ObjectField_t {
 /* @class Any3 Any knh_Any_t @Cyclic  @Private */
 
 struct knh_Glue_t;
-typedef void (*knh_fgluefree)(Ctx *, void *ptr, knh_ftraverse ftr);
-//typedef Object* (*knh_fccopy)(Ctx *ctx, struct knh_Glue_t *ptr);
+typedef void (*knh_fgfree)(Ctx *, struct knh_Glue_t *o, knh_ftraverse ftr);
 
 typedef struct knh_Glue_t {
 	knh_hObject_t h;
 	void *ptr;
-	knh_fgluefree gluefree;
+	knh_fgfree gfree;
 } knh_Glue_t ;
 
 #define CLASS_Glue    CLASS_Any
@@ -532,8 +531,7 @@ typedef struct knh_ClassSpec_t {
 } knh_ClassSpec_t ;
 
 #define ClassSpec        knh_ClassSpec_t
-
-typedef knh_ClassSpec_t* (*f_makespec)(Ctx *ctx, knh_class_t bcid, char *extra);
+typedef knh_ClassSpec_t* (*knh_fspec)(Ctx *ctx, knh_class_t bcid, char *extra);
 
 /* ------------------------------------------------------------------------ */
 /* @class IntUnit Object knh_IntUnit_struct @Private */
@@ -552,9 +550,6 @@ typedef struct knh_IntUnit {
 	knh_integer_t min;
 	knh_integer_t max;
 	knh_integer_t step;
-//	knh_int_t bfoffset;
-//	size_t bfsize;
-//	knh_Int_t** bfarray;
 } knh_IntUnit_struct;
 
 /* ------------------------------------------------------------------------ */
@@ -764,21 +759,21 @@ typedef struct knh_Script_t {
 /* ------------------------------------------------------------------------ */
 /* @class NameSpace Object knh_NameSpace_struct @Private */
 
-typedef int (*f_pkginit)(Ctx *ctx);
-typedef void (*f_pkgtraverse)(Ctx *ctx, knh_ftraverse ftr);
-
-typedef struct knh_pkgmeta_t {
-	const int buildid;
-	const char *name;  /* "unix" */
-	const char *version; /* "version" */
-	const char *desc;
-	const char *url;
-	f_pkginit finit;
-	f_pkgtraverse ftraverse;
-	const char *script;
-} knh_pkgmeta_t;
-
-typedef knh_pkgmeta_t* (*f_pkgload)(Ctx *ctx);
+//typedef int (*f_pkginit)(Ctx *ctx);
+//typedef void (*f_pkgtraverse)(Ctx *ctx, knh_ftraverse ftr);
+//
+//typedef struct knh_pkgmeta_t {
+//	const int buildid;
+//	const char *name;  /* "unix" */
+//	const char *version; /* "version" */
+//	const char *desc;
+//	const char *url;
+//	f_pkginit finit;
+//	f_pkgtraverse ftraverse;
+//	const char *script;
+//} knh_pkgmeta_t;
+//
+//typedef knh_pkgmeta_t* (*f_pkgload)(Ctx *ctx);
 
 typedef struct knh_NameSpace {
 	struct knh_NameSpace_t* parent;
@@ -789,8 +784,8 @@ typedef struct knh_NameSpace {
 	struct knh_DictMap_t*   lconstDictMap;
 	struct knh_DictMap_t*   tag2urnDictMap;
 	struct knh_Script_t*    script;
-	void                   *dlhdr;
-	knh_pkgmeta_t          *pkgmeta;
+//	void                   *dlhdr;
+//	knh_pkgmeta_t          *pkgmeta;
 } knh_NameSpace_struct;
 
 /* ------------------------------------------------------------------------ */
