@@ -298,8 +298,6 @@ knh_class_t knh_NameSpace_getFuncClass(Ctx *ctx, NameSpace *o, knh_bytes_t funcn
 knh_bool_t knh_NameSpace_existsConst(Ctx *ctx, NameSpace *o, knh_bytes_t name);
 void knh_NameSpace_addConst(Ctx *ctx, NameSpace *o, String *name, Object *value);
 Object* knh_NameSpace_getConst(Ctx *ctx, NameSpace *o, knh_bytes_t name);
-void knh_NameSpace_loaded(Ctx *ctx, NameSpace *o, knh_fileid_t fileid);
-knh_bool_t knh_NameSpace_isLoaded(Ctx *ctx, NameSpace *o, knh_fileid_t fileid);
 /* ../src/class/knh_Number.c */
 knh_integer_t knh_Number_tointeger(Any *o);
 knh_float_t knh_Number_tofloat(Any *o);
@@ -434,11 +432,15 @@ void knh_Asm_genMethod(Ctx *ctx, Asm *abr, OutputStream *w);
 void knh_Asm_loadCompiledMethod(Ctx *ctx, Asm *abr);
 knh_fmethod knh_Asm_getCompiledMethod(Ctx *ctx, Asm *abr, knh_bytes_t cname, knh_bytes_t mname);
 /* ../src/compiler/konohac.c */
-int konohac_compile(Ctx *ctx, String *nsname, Stmt *stmt_head, int isEval);
+int knh_Stmt_complie(Ctx *ctx, Stmt *stmt, String *nsname, int isEval);
+Stmt *knh_bytes_parseStmt(Ctx *ctx, knh_bytes_t kscript);
 void konohac_eval(Ctx *ctx, String *nsname, InputStream *in);
-Stmt *konoha_parse(Ctx *ctx, char *kscript);
+void knh_Asm_openlib(Ctx *ctx, Asm *abr, knh_bytes_t fpath);
+int knh_NameSpace_load(Ctx *ctx, NameSpace *ns, knh_bytes_t fpath, int isEval);
+void konoha_compile(Ctx *ctx, String *nsname, knh_bytes_t fpath);
 /* ../src/compiler/parser.c */
 Stmt *new_StmtINSTMT(Ctx *ctx, Token *tk);
+int knh_Token_isNEW(Ctx *ctx, Token *tk);
 void knh_Stmt_add_PEACH(Ctx *ctx, Stmt *o, knh_tokens_t *tc);
 /* ../src/compiler/perror.c */
 void knh_perrata(Ctx *ctx, knh_fileid_t fileid, int line, char *oldt, char *newt);
@@ -457,7 +459,6 @@ void knh_Stmt_add(Ctx *ctx, Stmt *o, Term *tm);
 Stmt *knh_Stmt_tail(Stmt *o);
 Stmt* knh_StmtNULL_tail_append(Ctx *ctx, Stmt *o, Stmt *stmt);
 knh_bool_t knh_Stmt_hasMeta(Stmt *o);
-knh_flag_t knh_StmtCLASS_flag(Ctx *ctx, Stmt *o);
 knh_flag_t knh_StmtMETHOD_flag(Ctx *ctx, Stmt *o);
 knh_flag_t knh_Stmt_metaflag__field(Ctx *ctx, Stmt *b);
 knh_flag_t knh_StmtPRINT_flag(Ctx *ctx, Stmt *o);
@@ -566,15 +567,8 @@ METHOD knh__Script_hook(Ctx *ctx, knh_sfp_t *sfp);
 void KNH_ACLASS(Ctx *ctx, knh_class_t cid, knh_class_t p1);
 void KNH_ICLASS(Ctx *ctx, knh_class_t cid, knh_class_t p1);
 knh_class_t KNH_XCLASS(Ctx *ctx, knh_class_t cid, knh_class_t bcid, ClassSpec *cs);
-knh_class_t knh_tClass_findcid(Ctx *ctx, knh_bytes_t lname);
-/* ../src/main/knh_tConst.c */
-knh_bool_t knh_tConst_exists(Ctx *ctx, knh_bytes_t name);
-Object *knh_tConst_value(Ctx *ctx, knh_bytes_t name);
-knh_bool_t knh_tConst_addClassConst(Ctx *ctx, knh_class_t cid, knh_bytes_t name, Object *value);
-void KNH_TCONST(Ctx *ctx, String *name, Object *value);
-knh_bool_t knh_tConst_addGlobalConst(Ctx *ctx, String *name, Object *value);
-void knh_tConst__man(Ctx *ctx, knh_class_t cid, OutputStream *w);
-Object *knh_tConst_systemValue(Ctx *ctx, int n);
+knh_class_t konoha_getcid(Ctx *ctx, char *lname);
+knh_class_t konoha_findcid(Ctx *ctx, knh_bytes_t lname);
 /* ../src/main/knh_tMapper.c */
 void konoha_addMapper(Ctx *ctx, knh_flag_t flag, knh_type_t stype, knh_type_t ttype, knh_fmapper fmap, Object *mapdata);
 MAPPER knh_Mapper_fInterface(Ctx *ctx, knh_sfp_t *sfp);
@@ -591,15 +585,6 @@ MethodField *knh_tMethodField_find0(Ctx *ctx, knh_type_t rtype);
 Method* knh_Class_getMethod__(Ctx *ctx, knh_class_t this_cid, knh_methodn_t mn, knh_bool_t gen);
 Method *knh_Method_ufind(Ctx *ctx, knh_class_t cid, knh_methodn_t mn);
 Method *knh_tMethod_findMT(Ctx *ctx, knh_class_t cid, knh_methodn_t mn);
-/* ../src/main/knh_tPackage.c */
-void KNH_TDRVAPI(Ctx *ctx, char *alias, knh_drvapi_t* p);
-knh_drvapi_t *knh_System_getDRVAPI(Ctx *ctx, int type, knh_bytes_t name);
-METHOD knh__System_hasLibrary(Ctx *ctx, knh_sfp_t *sfp);
-char *knh_format_packagedir(char *buf, size_t bufsiz, char *homedir);
-char *knh_format_packagepath(Ctx *ctx, char *buf, size_t bufsiz, char *pre, char *name, char *ext);
-int knh_System_using(Ctx *ctx, knh_bytes_t name);
-NameSpace *knh_Runtime_getNameSpace(Ctx *ctx, knh_bytes_t name);
-ClassSpec *knh_System_loadClassSpec(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn);
 /* ../src/main/konoha_api.c */
 void konoha_init(void);
 METHOD knh__Script_eval(Ctx *ctx, knh_sfp_t *sfp);
@@ -625,7 +610,6 @@ char * knh_format_catpath(char *buf, size_t bufsiz, knh_bytes_t path, knh_bytes_
 /* ../src/main/konoha_locale.c */
 char *konoha_encoding();
 char *knh_format_lang(char *buf, size_t bufsiz);
-/* ../src/main/konoha_pkgapi.c */
 /* ../src/main/konoha_print.c */
 void knh_stack_pmsg(Ctx *ctx, knh_sfp_t *sfp, knh_flag_t flag, String *s);
 void knh_stack_p(Ctx *ctx, knh_sfp_t *sfp, knh_flag_t flag, knh_methodn_t mn, int sfpidx);
@@ -654,17 +638,27 @@ int knh_sfp_argc(Ctx *ctx, knh_sfp_t *varg);
 char * knh_format_mtdparam(Ctx *ctx, char *buf, size_t bufsiz, Method *mtd, int n); void knh_sfp_typecheck(Ctx *ctx, knh_sfp_t *sfp, Method *mtd, knh_code_t *pc);
 void knh_sfp_dump(Ctx *ctx, knh_sfp_t *sfp);
 /* ../src/main/system.c */
+int konoha_existsConst(Ctx *ctx, knh_bytes_t name);
+Object *konoha_getConst(Ctx *ctx, knh_bytes_t name);
+void konoha_addConst(Ctx *ctx, String *name, Object *value);
+void knh_Const__man(Ctx *ctx, knh_class_t cid, OutputStream *w);
+Object *konoha_getSystemConst(Ctx *ctx, int n);
 int knh_bytes_isOptionalMT(knh_bytes_t t);
 knh_bytes_t knh_bytes_mtoption(knh_bytes_t t);
 char *knh_format_newFMT(char *buf, size_t bufsiz, knh_bytes_t t, int dot, char *fmt);
-String *knh_tfieldn_name(Ctx *ctx, knh_fieldn_t fn);
+String *konoha_getFieldName(Ctx *ctx, knh_fieldn_t fn);
 knh_fieldn_t knh_tName_get_fnq(Ctx *ctx, knh_bytes_t tname, knh_fieldn_t def);
 String *new_String__mn(Ctx *ctx, knh_methodn_t mn);
 knh_methodn_t knh_tName_getMethodn(Ctx *ctx, knh_bytes_t tname, knh_methodn_t def);
 char *knh_format_methodn(Ctx *ctx, char *buf, size_t bufsiz, knh_methodn_t mn);
 char * knh_format_cmethodn(Ctx *ctx, char *buf, size_t bufsiz, knh_class_t cid, knh_methodn_t mn);
-knh_fileid_t knh_tName_getFileId(Ctx *ctx, knh_bytes_t t);
-String *knh_tfileid_name(Ctx *ctx, knh_fileid_t fileid);
+knh_fileid_t konoha_getFileId(Ctx *ctx, knh_bytes_t t);
+String *konoha_getFileName(Ctx *ctx, knh_fileid_t fileid);
+void konoha_addDriverAPI(Ctx *ctx, char *alias, knh_drvapi_t* p);
+knh_drvapi_t *konoha_getDriverAPI(Ctx *ctx, int type, knh_bytes_t name);
+NameSpace *knh_System_loadPackage(Ctx *ctx, knh_bytes_t pkgname);
+NameSpace *knh_System_getNameSpace(Ctx *ctx, knh_bytes_t name);
+ClassSpec *konoha_getClassSpec(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn);
 /* ../src/main/systemtable.c */
 void konoha_initContext(Ctx *ctx, knh_Context_t *o, size_t stacksize);
 void knh_Context_traverse(Ctx *ctx, knh_Context_t *o, knh_ftraverse ftr);
