@@ -593,7 +593,7 @@ static knh_ClassData_t ClassData[] = {
 	{"konoha.ExceptionHandler", CLASS_ExceptionHandler, CFLAG_ExceptionHandler, STRUCT_ExceptionHandler, CLASS_Object, 0, 0, 0, knh_ExceptionHandler_fdefault},
 	{"konoha.Script", CLASS_Script, CFLAG_Script, STRUCT_Script, CLASS_Object, 0, 9, 0, knh_Script_fdefault},
 	{"konoha.NameSpace", CLASS_NameSpace, CFLAG_NameSpace, STRUCT_NameSpace, CLASS_Object, 0, 0, 0, knh_NameSpace_fdefault},
-	{"konoha.System", CLASS_System, CFLAG_System, STRUCT_System, CLASS_Object, 0, 15, 0, knh_System_fdefault},
+	{"konoha.System", CLASS_System, CFLAG_System, STRUCT_System, CLASS_Object, 0, 14, 0, knh_System_fdefault},
 	{"konoha.Context", CLASS_Context, CFLAG_Context, STRUCT_Context, CLASS_Object, 0, 16, 0, knh_Context_fdefault},
 	{"konoha.Token", CLASS_Token, CFLAG_Token, STRUCT_Token, CLASS_Object, 0, 3, 0, knh_Token_fdefault},
 	{"konoha.Stmt", CLASS_Stmt, CFLAG_Stmt, STRUCT_Stmt, CLASS_Object, 0, 2, 0, knh_Stmt_fdefault},
@@ -629,22 +629,8 @@ static knh_ExptData_t ExptData[] = {
 	{NULL, 0}
 };
 
-int knhiroha_load(Ctx *ctx);
-int knhunix_load(Ctx *ctx);
-int knhsocket_load(Ctx *ctx);
-int knhnaruto_load(Ctx *ctx);
-int knhcgi_load(Ctx *ctx);
-int knhdemo_load(Ctx *ctx);
-int knhmath_load(Ctx *ctx);
 static knh_FuncData_t FuncData[] = {
 #ifdef KONOHA_MONOLITHIC
-	{"knhiroha_load", (void*)knhiroha_load},
-	{"knhunix_load", (void*)knhunix_load},
-	{"knhsocket_load", (void*)knhsocket_load},
-	{"knhnaruto_load", (void*)knhnaruto_load},
-	{"knhcgi_load", (void*)knhcgi_load},
-	{"knhdemo_load", (void*)knhdemo_load},
-	{"knhmath_load", (void*)knhmath_load},
 #endif/*KONOHA_MONOLITHIC*/
 	{NULL}
 };
@@ -701,7 +687,6 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"flush", FIELDN_flush},
 	{"format", FIELDN_format},
 	{"formatted", FIELDN_formatted},
-	{"func", FIELDN_func},
 	{"funcname", FIELDN_funcname},
 	{"g", FIELDN_g},
 	{"gCMarked", FIELDN_gCMarked},
@@ -709,7 +694,6 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"h", FIELDN_h},
 	{"hasDir", FIELDN_hasDir},
 	{"hasFile", FIELDN_hasFile},
-	{"hasLibrary", FIELDN_hasLibrary},
 	{"hasMetaData", FIELDN_hasMetaData},
 	{"hook", FIELDN_hook},
 	{"i", FIELDN_i},
@@ -767,7 +751,6 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"lambda", FIELDN_lambda},
 	{"lastIndexOf", FIELDN_lastIndexOf},
 	{"len", FIELDN_len},
-	{"lib", FIELDN_lib},
 	{"linenum", FIELDN_linenum},
 	{"listProperties", FIELDN_listProperties},
 	{"m", FIELDN_m},
@@ -985,7 +968,6 @@ static knh_MethodFieldData_t MethodFieldData[] = {
 	{MFN_String, 0+ 0, TYPE_String},
 	{MFN_nThis, 0+ 0, NNTYPE_This},
 	{MFN_nBoolean_nRegex, 1+ 0, NNTYPE_Boolean, NNTYPE_Regex, FIELDN_r},
-	{MFN_nBoolean_nString_String, 2+ 0, NNTYPE_Boolean, NNTYPE_String, FIELDN_l, TYPE_String, FIELDN_f},
 	{MFN_void_String_String_Int, 3+ 0, TYPE_void, TYPE_String, FIELDN_s, TYPE_String, FIELDN_f, TYPE_Int, FIELDN_l},
 	{MFN_String_String, 1+ 0, TYPE_String, TYPE_String, FIELDN_p},
 	{MFN_Boolean_nClass, 1+ 0, TYPE_Boolean, NNTYPE_Class, FIELDN_c},
@@ -1294,7 +1276,6 @@ static knh_MethodData_t MethodData[] = {
 	{knh__Script_fibo, 0, CLASS_Script, METHODN_fibo, 0, MFN_nInt_nInt, (void*)NULL},
 	{knh__Script_changeChannel, 0, CLASS_Script, METHODN_changeChannel, 0, MFN_void_nInt, (void*)NULL},
 	{knh__Script_hook, 0, CLASS_Script, METHODN_hook, 0, MFN_void_nString, (void*)NULL},
-	{knh__System_hasLibrary, KNH_FLAG_MF_STATIC, CLASS_System, METHODN_hasLibrary, 0, MFN_nBoolean_nString_String, (void*)NULL},
 	{knh__Script_eval, 0, CLASS_Script, METHODN_eval, 0, MFN_void_String_String_Int, (void*)NULL},
 	{knh__Script_isStatement, 0, CLASS_Script, METHODN_isStatement, 0, MFN_nBoolean_nString, (void*)NULL},
 	{knh__Script_readLine, 0, CLASS_Script, METHODN_readLine, 0, MFN_String_String, (void*)NULL},
