@@ -272,12 +272,32 @@ typedef knh_uint64_t       knh_uinteger_t;
 typedef unsigned char           knh_uchar_t;    /* byte */
 
 typedef struct {
-	knh_uchar_t   *buf;
+	knh_uchar_t *buf;
 	size_t     len;
 } knh_bytes_t;
 
 #define ismulti(c)             (((knh_uchar_t)c)>127)
 
+
+/* ------------------------------------------------------------------------ */
+/* ConstData  */
+/* ------------------------------------------------------------------------ */
+
+typedef struct {
+	char *name;
+	knh_integer_t ivalue;
+} knh_IntConstData_t;
+
+typedef struct {
+	char *name;
+	knh_float_t fvalue;
+} knh_FloatConstData_t;
+
+typedef struct {
+	char *name;
+	char *value;
+} knh_StringConstData_t;
+
 /* ------------------------------------------------------------------------ */
 /* Struct, Class, Type  */
 /* ------------------------------------------------------------------------ */
@@ -410,7 +430,7 @@ typedef unsigned char           knh_code_t;          /* knh_vmc_t */
 #define p_bytes(a)       (knh_Bytes_tobytes(a.s))
 #define p_cid(a)         ((a.c)->cid)
 #define ARG_Object_cid(a)  knh_Object_cid(a.o)
-#define p_cptr(a)        ((a.n)->cptr)
+#define p_cptr(a)        ((a.glue)->ptr)
 
 /* ------------------------------------------------------------------------ */
 
@@ -425,7 +445,7 @@ typedef struct knh_sfp_t {
 		struct knh_Bytes_t  *ba;
 		struct knh_Iterator_t *it;
 		struct knh_Closure_t *cc;
-		struct knh_Glue_t   *n;
+		struct knh_Glue_t   *glue;
 		struct knh_OutputStream_t *w;
 		struct knh_Method_t *mtd;
 		struct knh_Mapper_t *mpr;
@@ -574,6 +594,7 @@ char *konoha_getStructName(Ctx *ctx, knh_struct_t sid);
 
 typedef void (*knh_fgchook)(Ctx *ctx);
 typedef void (*knh_ftraverse)(Ctx *ctx, Object *);
+typedef int (*knh_finit)(Ctx *);
 
 typedef knh_uint_t                knh_hcode_t;  /* knh_hcode_t */
 #define knh_hcode_join(s1,s2)	   ((knh_hcode_t)s1 << (sizeof(knh_short_t)*8)) + s2;
@@ -751,7 +772,7 @@ typedef struct knh_Context_t {
 
 	knh_flag_t                   flag;
 	knh_ushort_t                 ctxid;
-	char*                        doing;
+	char*                        cwd;
 	struct knh_String_t*         enc;
 	struct knh_InputStream_t*    in;
 	struct knh_OutputStream_t*   out;
