@@ -34,17 +34,18 @@
 extern "C" {
 #endif
 
+#ifdef OLDVM
 /* ======================================================================== */
 
 #define VM_DEBUG_ASSERT(c)        KNH_ASSERT(c)
 
-int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
+int knh_Method_pctoline(Method *mtd, knh_code_t *pc);
 #define _HERE_    knh_Method_file(sfp[-1].mtd), knh_Method_pctoline(sfp[-1].mtd, pc)
 
 /* ======================================================================== */
 
-//#define ebp_(n)                   ((Context*)ctx)->ebp[n]
-#define ebp_(n)                   ((Context*)ctx)->ebp[(n)].o
+//#define esp_(n)                   ((Context*)ctx)->esp[n]
+#define esp_(n)                   ((Context*)ctx)->esp[(n)].o
 #define sfp_(n)                   sfp[(n)].o
 #define ofp_(n)                   KNH_FIELDn(sfp[0].o, (n))
 #define oidx_(o,idx)              KNH_FIELDn((o), (idx))
@@ -61,7 +62,7 @@ int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 /* ======================================================================== */
 
 #define NPC
-#define VM_EBP(ctx,n)             ((Context*)ctx)->ebp[n].o
+#define VM_ESP(ctx,n)             ((Context*)ctx)->esp[n].o
 //#define VM_FILE                   ""
 //#define VM_LINE                   0
 
@@ -71,34 +72,6 @@ int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 
 /* ======================================================================== */
 
-#define KNH_RETURN(ctx, sfp, v)      {\
-		KNH_NGCSETv(ctx, sfp[-1].o, v); \
-		return; \
-	}\
-
-#define KNH_RETURN_void(ctx, sfp)      {\
-		KNH_NGCSETv(ctx, sfp[-1].o, KNH_VOID); \
-		return; \
-	}\
-
-#define KNH_RETURN_Boolean(ctx, sfp, c)      {\
-		if((c)) { \
-			KNH_NGCSETv(ctx, sfp[-1].o, KNH_TRUE); \
-		}else { \
-			KNH_NGCSETv(ctx, sfp[-1].o, KNH_FALSE); \
-		} \
-		return; \
-	}\
-
-#define KNH_RETURN_Int(ctx, sfp, n)      {\
-		KNH_NGCSETv(ctx, sfp[-1].o, new_Int(ctx, (knh_int_t)(n))); \
-		return; \
-	}\
-
-#define KNH_RETURN_Float(ctx, sfp, n)      {\
-		KNH_NGCSETv(ctx, sfp[-1].o, new_Float(ctx, (knh_float_t)(n))); \
-		return; \
-	}\
 
 /* ======================================================================== */
 
@@ -164,11 +137,11 @@ int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 	}\
 
 #define VM_BBOXE(ctx, n) { \
-		KNH_SETv(ctx, ebp[n].o, ebp[n].bvalue == 0 ? KNH_FALSE : KNH_TRUE);\
+		KNH_SETv(ctx, esp[n].o, esp[n].bvalue == 0 ? KNH_FALSE : KNH_TRUE);\
 	}\
 
 #define VM_BUNBOXE(ctx, n) { \
-		ebp[n].bvalue = IS_TRUE(ebp[n].o);\
+		esp[n].bvalue = IS_TRUE(esp[n].o);\
 	}\
 
 #define VM_IBOXS(ctx, n) { \
@@ -180,11 +153,11 @@ int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 	}\
 
 #define VM_IBOXE(ctx, n) { \
-		KNH_SETv(ctx, ebp[n].o, new_Int(ctx, ebp[n].ivalue));\
+		KNH_SETv(ctx, esp[n].o, new_Int(ctx, esp[n].ivalue));\
 	}\
 
 #define VM_IUNBOXE(ctx, n) { \
-		ebp[n].ivalue = (ebp[n].i)->value;\
+		esp[n].ivalue = (esp[n].i)->value;\
 	}\
 
 #define VM_FBOXS(ctx, n) { \
@@ -196,95 +169,95 @@ int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 	}\
 
 #define VM_FBOXE(ctx, n) { \
-		KNH_SETv(ctx, ebp[n].o, new_Int(ctx, ebp[n].fvalue));\
+		KNH_SETv(ctx, esp[n].o, new_Int(ctx, esp[n].fvalue));\
 	}\
 
 #define VM_FUNBOXE(ctx, n) { \
-		ebp[n].fvalue = (ebp[n].f)->value;\
+		esp[n].fvalue = (esp[n].f)->value;\
 	}\
 
 /* ======================================================================== */
 
 #define _VM_PUT_(ctx,v) \
-	VM_MOV(ctx, ((Context*)ctx)->ebp[0].o, v); \
+	VM_MOV(ctx, ((Context*)ctx)->esp[0].o, v); \
 
 #define _VM_PUTI_(ctx,i) \
-	((Context*)ctx)->ebp[0].op = (knh_stackop_t)i; \
+	((Context*)ctx)->esp[0].op = (knh_stackop_t)i; \
 
 #define _VM_PUSHI_(ctx,v) \
-	((Context*)ctx)->ebp++; \
-	((Context*)ctx)->ebp[0].op = (knh_stackop_t)v; \
+	((Context*)ctx)->esp++; \
+	((Context*)ctx)->esp[0].op = (knh_stackop_t)v; \
 
 #define _VM_PUSH__MN_(ctx,mn) \
-	((Context*)ctx)->ebp++; \
-	((Context*)ctx)->ebp[0].op = (knh_uint_t)mn; \
+	((Context*)ctx)->esp++; \
+	((Context*)ctx)->esp[0].op = (knh_uint_t)mn; \
 
 #define VM_PUSH(ctx,v) \
-	((Context*)ctx)->ebp++; \
-	VM_MOV(ctx, ((Context*)ctx)->ebp[0].o, v); \
+	((Context*)ctx)->esp++; \
+	VM_MOV(ctx, ((Context*)ctx)->esp[0].o, v); \
 
 #define VM_PUSH__OIDX(ctx, v, idx) \
-	((Context*)ctx)->ebp++; \
-	VM_MOV(ctx, ((Context*)ctx)->ebp[0].o, oidx_(v,idx)); \
+	((Context*)ctx)->esp++; \
+	VM_MOV(ctx, ((Context*)ctx)->esp[0].o, oidx_(v,idx)); \
 
 #define VM_SHIFT(ctx,n) \
-	((Context*)ctx)->ebp += (n); \
+	((Context*)ctx)->esp += (n); \
 
 #define VM_PUSH__DEF(ctx, cid) \
-	((Context*)ctx)->ebp++; \
-	KNH_SETv(ctx, ((Context*)ctx)->ebp[0].o, knh_tClass_defaultValue(ctx, TYPE_UNMASK(cid))); \
+	((Context*)ctx)->esp++; \
+	KNH_SETv(ctx, ((Context*)ctx)->esp[0].o, knh_tClass_defaultValue(ctx, CLASS_type(cid))); \
 
-#define VM_CONST_CTX    0
-#define VM_CONST_STDIN  1
-#define VM_CONST_STDOUT 2
-#define VM_CONST_STDERR 3
+#define KNH_SYS_CTX    0
+#define KNH_SYS_STDIN  1
+#define KNH_SYS_STDOUT 2
+#define KNH_SYS_STDERR 3
 
 #define VM_PUT_SYSCONST(ctx, n) { \
-		VM_MOV(ctx, ((Context*)ctx)->ebp[0].o, knh_tConst_systemValue(ctx, n)); \
+		VM_MOV(ctx, ((Context*)ctx)->esp[0].o, knh_tConst_systemValue(ctx, n)); \
 	}\
 
 #define VM_PUSH_SYSCONST(ctx, n) { \
-		((Context*)ctx)->ebp++; \
-		VM_MOV(ctx, ((Context*)ctx)->ebp[0].o, knh_tConst_systemValue(ctx, n)); \
+		((Context*)ctx)->esp++; \
+		VM_MOV(ctx, ((Context*)ctx)->esp[0].o, knh_tConst_systemValue(ctx, n)); \
 	}\
 
 #define VM_VARGV(ctx, n) { \
 		KNH_SETv(ctx, sfp[n].o, knh_sfp_toArray(ctx, &sfp[n-1])); \
-		((Context*)ctx)->ebp = &sfp[n]; \
+		((Context*)ctx)->esp = &sfp[n]; \
 	} \
 
 /* ------------------------------------------------------------------------ */
 
 #define KNH_CHECKSTACK(ctx) \
-	if(unlikely((ctx)->stacksize - ((ctx)->ebp - (ctx)->stack) < 256)) {\
+	if(unlikely((ctx)->stacksize - ((ctx)->esp - (ctx)->stack) < 256)) {\
 		KNH_THROWs(ctx, "StackOverflow!!"); \
 	}\
 
 #define KNH_SCALL(ctx, n) { \
 		KNH_CHECKSTACK(ctx); \
-		knh_sfp_t *mbp_ = ctx->ebp - (n) ; \
+		knh_sfp_t *mbp_ = ctx->esp - (n) ; \
 		KNH_CHECKSTACK(ctx); \
 		KNH_ASSERT(IS_Method(mbp_[0].mtd)); \
 		mbp_[0].op = 0; \
 		(mbp_[0].mtd)->fcall_1(ctx, mbp_ + 1); \
 		mbp_[0].op = 0; \
-		((Context*)ctx)->ebp = mbp_; \
+		((Context*)ctx)->esp = mbp_; \
 	} \
 
 #define VM_SCALL(ctx, n) { \
 		KNH_CHECKSTACK(ctx); \
-		knh_sfp_t *mbp_ = ((Context*)ctx)->ebp - (n) ; \
+		knh_sfp_t *mbp_ = ((Context*)ctx)->esp - (n) ; \
 		KNH_ASSERT(IS_Method(mbp_[0].mtd)); \
 		KNH_ASSERT(IS_NOTNULL(mbp_[1].o) || knh_Method_isNullBase(mbp_[0].mtd)); \
 		mbp_[0].op = (knh_stackop_t)pc; \
 		(mbp_[0].mtd)->fcall_1(ctx, mbp_ + 1); \
 		mbp_[0].op = 0; \
-		((Context*)ctx)->ebp = mbp_; \
+		((Context*)ctx)->esp = mbp_; \
 	} \
 
 #define VM_NSCALL(ctx, n) { \
 		KNH_CHECKSTACK(ctx); \
-		knh_sfp_t *mbp_ = ((Context*)ctx)->ebp - (n) ; \
+		knh_sfp_t *mbp_ = ((Context*)ctx)->esp - (n) ; \
 		if(unlikely(IS_NULL(mbp_[1].o))) { \
 			knh_throwException(ctx, new_Exception__Nue(ctx, (Nue*)(mbp_[1].o)), _HERE_); \
 		} \
@@ -294,80 +267,80 @@ int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 			(mbp_[0].mtd)->fcall_1(ctx, mbp_ + 1); \
 			mbp_[0].op = 0; \
 		} \
-		((Context*)ctx)->ebp = mbp_; \
+		((Context*)ctx)->esp = mbp_; \
 	} \
 
 #define VM_CALL(ctx, n, mn) { \
 		KNH_CHECKSTACK(ctx); \
-		knh_sfp_t *mbp_ = ctx->ebp - (n) ; \
+		knh_sfp_t *mbp_ = ctx->esp - (n) ; \
 		KNH_SETv(ctx, mbp_[0].o, knh_Method_ufind(ctx, knh_Object_cid(mbp_[1].o), mn)); \
 		KNH_ASSERT(IS_Method(mbp_[0].mtd)); \
 		mbp_[0].op = (knh_stackop_t)pc; \
 		(mbp_[0].mtd)->fcall_1(ctx, mbp_ + 1); \
 		mbp_[0].op = 0; \
-		((Context*)ctx)->ebp = mbp_; \
+		((Context*)ctx)->esp = mbp_; \
 	} \
 
 #define VM_DCALL(ctx, n, mn) { \
 		KNH_CHECKSTACK(ctx); \
-		knh_sfp_t *mbp_ = ((Context*)ctx)->ebp - (n) ; \
+		knh_sfp_t *mbp_ = ((Context*)ctx)->esp - (n) ; \
 		KNH_SETv(ctx, mbp_[0].o, knh_Method_ufind(ctx, knh_Object_cid(mbp_[1].o), mn)); \
 		KNH_ASSERT(IS_Method(mbp_[0].mtd)); \
 		mbp_[0].op = (knh_stackop_t)pc; \
 		knh_dynamiccall(ctx, mbp_); \
 		(mbp_[0].mtd)->fcall_1(ctx, mbp_ + 1); \
 		mbp_[0].op = 0; \
-		((Context*)ctx)->ebp = mbp_; \
+		((Context*)ctx)->esp = mbp_; \
 	} \
 
 
 #define VM_SMAP(ctx, mpr)  { \
 		knh_Mapper_t *mpr_ = (knh_Mapper_t*)mpr; \
 		VM_DEBUG_ASSERT(IS_Mapper(mpr)); \
-		KNH_SETv(ctx, ebp_(0), (mpr_)->fmap_1(ctx, ebp_(0), mpr_)); \
+		KNH_SETv(ctx, esp_(0), (mpr_)->fmap_1(ctx, esp_(0), mpr_)); \
 	} \
 
 #define KNH_SMAP(ctx, mpr)  { \
 		knh_Mapper_t *mpr_ = (knh_Mapper_t*)mpr; \
-		KNH_SETv(ctx, ebp_(0), (mpr_)->fmap_1(ctx, ebp_(0), mpr_)); \
+		KNH_SETv(ctx, esp_(0), (mpr_)->fmap_1(ctx, esp_(0), mpr_)); \
 	} \
 
 #define VM_SMAPE(ctx, mpr)  { \
 		knh_Mapper_t *mpr_ = (knh_Mapper_t*)mpr; \
 		VM_DEBUG_ASSERT(IS_Mapper(mpr)); \
-		KNH_SETv(ctx, ebp_(0), (mpr_)->fmap_1(ctx, ebp_(0), mpr_)); \
-		if(unlikely(IS_NULL(ebp_(0)))) { \
-			knh_throwException(ctx, new_Exception__Nue(ctx, (Nue*)ebp_(0)), _HERE_); \
+		KNH_SETv(ctx, esp_(0), (mpr_)->fmap_1(ctx, esp_(0), mpr_)); \
+		if(unlikely(IS_NULL(esp_(0)))) { \
+			knh_throwException(ctx, new_Exception__Nue(ctx, (Nue*)esp_(0)), _HERE_); \
 		} \
 	} \
 
 #define VM_MAP(ctx, tcid)  { \
-		knh_Mapper_t *mpr_ = knh_tMapper_find(ctx, knh_Object_cid(ebp_(0)), tcid); \
-		KNH_SETv(ctx, ebp_(0), (mpr_)->fmap_1(ctx, ebp_(0), mpr_)); \
+		knh_Mapper_t *mpr_ = knh_tMapper_find(ctx, knh_Object_cid(esp_(0)), tcid); \
+		KNH_SETv(ctx, esp_(0), (mpr_)->fmap_1(ctx, esp_(0), mpr_)); \
 	} \
 
 #define VM_MAPE(ctx, tcid)  { \
-		knh_Mapper_t *mpr_ = knh_tMapper_find(ctx, knh_Object_cid(ebp_(0)), tcid); \
-		KNH_SETv(ctx, ebp_(0), (mpr_)->fmap_1(ctx, ebp_(0), mpr_)); \
-		if(IS_NULL(ebp_(0))) { \
-			knh_throwException(ctx, new_Exception__Nue(ctx, (Nue*)ebp_(0)), _HERE_); \
+		knh_Mapper_t *mpr_ = knh_tMapper_find(ctx, knh_Object_cid(esp_(0)), tcid); \
+		KNH_SETv(ctx, esp_(0), (mpr_)->fmap_1(ctx, esp_(0), mpr_)); \
+		if(IS_NULL(esp_(0))) { \
+			knh_throwException(ctx, new_Exception__Nue(ctx, (Nue*)esp_(0)), _HERE_); \
 		} \
 	} \
 
 #define VM_ANYMAP(ctx, tcid)  { \
-		if(knh_Object_cid(ebp_(0)) != tcid && !knh_class_instanceof(knh_Object_cid(ebp_(0)), tcid)) { \
-			knh_Mapper_t *mpr_ = knh_tMapper_find(ctx, knh_Object_cid(ebp_(0)), tcid); \
-			KNH_SETv(ctx, ebp_(0), (mpr_)->fmap_1(ctx, ebp_(0), mpr_)); \
+		if(knh_Object_cid(esp_(0)) != tcid && !knh_class_instanceof(ctx, knh_Object_cid(esp_(0)), tcid)) { \
+			knh_Mapper_t *mpr_ = knh_tMapper_find(ctx, knh_Object_cid(esp_(0)), tcid); \
+			KNH_SETv(ctx, esp_(0), (mpr_)->fmap_1(ctx, esp_(0), mpr_)); \
 		} \
 	} \
 
 #define VM_ANYMAPE(ctx, tcid)  { \
-		if(knh_Object_cid(ebp_(0)) != tcid && !knh_class_instanceof(knh_Object_cid(ebp_(0)), tcid)) { \
-			knh_Mapper_t *mpr_ = knh_tMapper_find(ctx, knh_Object_cid(ebp_(0)), tcid); \
-			KNH_SETv(ctx, ebp_(0), (mpr_)->fmap_1(ctx, ebp_(0), mpr_)); \
+		if(knh_Object_cid(esp_(0)) != tcid && !knh_class_instanceof(ctx, knh_Object_cid(esp_(0)), tcid)) { \
+			knh_Mapper_t *mpr_ = knh_tMapper_find(ctx, knh_Object_cid(esp_(0)), tcid); \
+			KNH_SETv(ctx, esp_(0), (mpr_)->fmap_1(ctx, esp_(0), mpr_)); \
 		} \
-		if(unlikely(IS_NULL(ebp_(0)))) { \
-			knh_throwException(ctx, new_Exception__Nue(ctx, (Nue*)ebp_(0)), _HERE_); \
+		if(unlikely(IS_NULL(esp_(0)))) { \
+			knh_throwException(ctx, new_Exception__Nue(ctx, (Nue*)esp_(0)), _HERE_); \
 		} \
 	} \
 
@@ -392,25 +365,25 @@ int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 	} \
 
 #define VM_NEW(ctx, n, flag, cid) { \
-		knh_sfp_t *mbp_ = ((Context*)ctx)->ebp - (n) ; \
+		knh_sfp_t *mbp_ = ((Context*)ctx)->esp - (n) ; \
 		KNH_ASSERT(IS_Method(mbp_[0].mtd)); \
 		KNH_SETv(ctx, mbp_[1].o, new_Object__init(ctx, flag, cid)); \
 		mbp_[0].op = (knh_stackop_t)pc; \
 		(mbp_[0].mtd)->fcall_1(ctx, mbp_ + 1); \
 		mbp_[0].op = 0; \
-		((Context*)ctx)->ebp = mbp_; \
+		((Context*)ctx)->esp = mbp_; \
 	} \
 
 #define VM_MT(ctx, mn) { \
-		knh_sfp_t *mbp_ = ((Context*)ctx)->ebp; \
-		KNH_SETv(ctx, ebp_(0), knh_Object_movableText(ctx, ebp_(0), mn, KNH_NULL)); \
-		((Context*)ctx)->ebp = mbp_; \
+		knh_sfp_t *mbp_ = ((Context*)ctx)->esp; \
+		KNH_SETv(ctx, esp_(0), knh_Object_movableText(ctx, esp_(0), mn, KNH_NULL)); \
+		((Context*)ctx)->esp = mbp_; \
 	} \
 
 #define VM_MT__FMT(ctx, mn, opt) { \
-		knh_sfp_t *mbp_ = ((Context*)ctx)->ebp; \
-		KNH_SETv(ctx, ebp_(0), knh_Object_movableText(ctx, ebp_(0), mn, opt)); \
-		((Context*)ctx)->ebp = mbp_; \
+		knh_sfp_t *mbp_ = ((Context*)ctx)->esp; \
+		KNH_SETv(ctx, esp_(0), knh_Object_movableText(ctx, esp_(0), mn, opt)); \
+		((Context*)ctx)->esp = mbp_; \
 	} \
 
 /* ------------------------------------------------------------------------- */
@@ -481,11 +454,11 @@ int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 		knh_Iterator_t *it_ = (knh_Iterator_t*)it; \
 		KNH_ASSERT(IS_bIterator(it_)); \
 		do { \
-			KNH_SETv(ctx, ebp_(0), (it_)->fnext_1(ctx, it_)); \
-			if(IS_NULL(ebp_(0))) { \
+			KNH_SETv(ctx, esp_(0), (it_)->fnext_1(ctx, it_)); \
+			if(IS_NULL(esp_(0))) { \
 				VM_JMP(ctx, PC, JUMP); \
 			} \
-			KNH_SETv(ctx, v, (mpr_)->fmap_1(ctx, ebp_(0), mpr_)); \
+			KNH_SETv(ctx, v, (mpr_)->fmap_1(ctx, esp_(0), mpr_)); \
 		}while(IS_NULL(v)); \
 	} \
 
@@ -493,12 +466,12 @@ int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 		knh_Iterator_t *it_ = (knh_Iterator_t*)it; \
 		KNH_ASSERT(IS_bIterator(it_)); \
 		do { \
-			KNH_SETv(ctx, ebp_(0), (it_)->fnext_1(ctx, it_)); \
-			if(IS_NULL(ebp_(0))) { \
+			KNH_SETv(ctx, esp_(0), (it_)->fnext_1(ctx, it_)); \
+			if(IS_NULL(esp_(0))) { \
 				VM_JMP(ctx, PC, JUMP); \
 			} \
-			knh_Mapper_t *mpr_ = knh_tMapper_find(ctx, knh_Object_cid(ebp_(0)), tcid); \
-			KNH_SETv(ctx, v, (mpr_)->fmap_1(ctx, ebp_(0), mpr_)); \
+			knh_Mapper_t *mpr_ = knh_tMapper_find(ctx, knh_Object_cid(esp_(0)), tcid); \
+			KNH_SETv(ctx, v, (mpr_)->fmap_1(ctx, esp_(0), mpr_)); \
 		}while(IS_NULL(v)); \
 	} \
 
@@ -621,21 +594,21 @@ int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 /* ------------------------------------------------------------------------ */
 
 #define VM_IADD(ctx) { \
-		((Context*)ctx)->ebp--; \
-		Object *n_ = UP(new_Int(ctx, ((Int*)(ebp_(0)))->value + ((Int*)(ebp_(1)))->value)); \
-		VM_MOV(ctx, ((Context*)ctx)->ebp[0].o, n_); \
+		((Context*)ctx)->esp--; \
+		Object *n_ = UP(new_Int(ctx, ((Int*)(esp_(0)))->value + ((Int*)(esp_(1)))->value)); \
+		VM_MOV(ctx, ((Context*)ctx)->esp[0].o, n_); \
 	}\
 
 #define VM_ISUB(ctx) { \
-		((Context*)ctx)->ebp--; \
-		Object *n_ = UP(new_Int(ctx, ((Int*)(ebp_(0)))->value - ((Int*)(ebp_(1)))->value)); \
-		VM_MOV(ctx, ((Context*)ctx)->ebp[0].o, n_); \
+		((Context*)ctx)->esp--; \
+		Object *n_ = UP(new_Int(ctx, ((Int*)(esp_(0)))->value - ((Int*)(esp_(1)))->value)); \
+		VM_MOV(ctx, ((Context*)ctx)->esp[0].o, n_); \
 	}\
 
 #define VM_ILT(ctx) { \
-		((Context*)ctx)->ebp--; \
-		Object *n_ = (((Int*)(ebp_(0)))->value < ((Int*)(ebp_(1)))->value) ? KNH_TRUE : KNH_FALSE ; \
-		VM_MOV(ctx, ((Context*)ctx)->ebp[0].o, n_); \
+		((Context*)ctx)->esp--; \
+		Object *n_ = (((Int*)(esp_(0)))->value < ((Int*)(esp_(1)))->value) ? KNH_TRUE : KNH_FALSE ; \
+		VM_MOV(ctx, ((Context*)ctx)->esp[0].o, n_); \
 	}\
 
 #define VM_NOP(ctx)
@@ -643,14 +616,11 @@ int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 /* ------------------------------------------------------------------------ */
 /* ------------------------------------------------------------------------ */
 
-#define KNH_SECURE(ctx) \
-	if(((ctx)->flag & KNH_FLAG_CTXF_ADMIN) != KNH_FLAG_CTXF_ADMIN) { \
-		knh_throwException(ctx, new_Exception(ctx, TS_SecurityException), KNH_SAFEFILE(__FILE__), __LINE__); \
-	} \
 
 
 /* ------------------------------------------------------------------------ */
 
+#endif
 
 #ifdef __cplusplus
 }
