@@ -35,13 +35,15 @@
 extern "C" {
 #endif
 
+#ifdef KNH_CC_METHODAPI
+
 /* ======================================================================== */
 /* [new] */
 
 /* ------------------------------------------------------------------------ */
 /* @method This! Array.new(Int init) */
 
-METHOD knh__Array_new(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_new(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	int init = IS_NULL(sfp[1].o) ? KNH_ARRAY_INITSIZE: p_int(sfp[1]);
@@ -55,7 +57,7 @@ METHOD knh__Array_new(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method This! Array.new:array(Int! n) */
 
-METHOD knh__Array_new__array(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_new__array(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	int init = p_int(sfp[1]);
@@ -71,7 +73,7 @@ METHOD knh__Array_new__array(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS] This! Array.new:init(Any1! value) @VARARGS */
 
-METHOD knh__Array_new__init(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_new__init(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	knh_sfp_t *v = sfp + 1;
@@ -89,7 +91,8 @@ METHOD knh__Array_new__init(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* [IArray] */
 
-static void knh_IArray_grow(Ctx *ctx, IArray *a, size_t newsize, knh_integer_t v)
+static
+void knh_IArray_grow(Ctx *ctx, IArray *a, size_t newsize, knh_integer_t v)
 {
 	KNH_ASSERT(a->capacity < newsize);
 	size_t i;
@@ -111,7 +114,8 @@ static void knh_IArray_grow(Ctx *ctx, IArray *a, size_t newsize, knh_integer_t v
 
 /* ------------------------------------------------------------------------ */
 
-static void knh_IArray_add(Ctx *ctx, IArray *o, knh_integer_t value)
+static
+void knh_IArray_add(Ctx *ctx, IArray *o, knh_integer_t value)
 {
 	if(o->size == o->capacity) {
 		knh_IArray_grow(ctx, o, knh_array_newsize(o->capacity * 2, sizeof(knh_integer_t)), 0);
@@ -124,7 +128,7 @@ static void knh_IArray_add(Ctx *ctx, IArray *o, knh_integer_t value)
 /* ------------------------------------------------------------------------ */
 /* @method This! IArray.new(Int init) */
 
-METHOD knh__IArray_new(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_new(Ctx *ctx, knh_sfp_t *sfp)
 {
 	IArray *o = (IArray*)sfp[0].o;
 	int init = IS_NULL(sfp[1].o) ? KNH_IARRAY_INITSIZE: p_int(sfp[1]);
@@ -138,7 +142,7 @@ METHOD knh__IArray_new(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method This! IArray.new:array(Int! n) */
 
-METHOD knh__IArray_new__array(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_new__array(Ctx *ctx, knh_sfp_t *sfp)
 {
 	IArray *o = (IArray*)sfp[0].o;
 	int init = p_int(sfp[1]);
@@ -152,7 +156,7 @@ METHOD knh__IArray_new__array(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS] This! IArray.new:init(Int! value) @VARARGS */
 
-METHOD knh__IArray_new__init(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_new__init(Ctx *ctx, knh_sfp_t *sfp)
 {
 	IArray *o = (IArray*)sfp[0].o;
 	knh_sfp_t *v = sfp + 1;
@@ -169,7 +173,8 @@ METHOD knh__IArray_new__init(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* [FArray] */
 
-static void knh_FArray_grow(Ctx *ctx, FArray *a, size_t newsize, knh_float_t v)
+static
+void knh_FArray_grow(Ctx *ctx, FArray *a, size_t newsize, knh_float_t v)
 {
 	KNH_ASSERT(a->capacity < newsize);
 	size_t i;
@@ -191,7 +196,8 @@ static void knh_FArray_grow(Ctx *ctx, FArray *a, size_t newsize, knh_float_t v)
 
 /* ------------------------------------------------------------------------ */
 
-static void knh_FArray_add(Ctx *ctx, FArray *o, knh_float_t value)
+static
+void knh_FArray_add(Ctx *ctx, FArray *o, knh_float_t value)
 {
 	if(o->size == o->capacity) {
 		knh_FArray_grow(ctx, o, knh_array_newsize(o->capacity * 2, sizeof(knh_float_t)), 0.0);
@@ -204,7 +210,7 @@ static void knh_FArray_add(Ctx *ctx, FArray *o, knh_float_t value)
 /* ------------------------------------------------------------------------ */
 /* @method This! FArray.new(Int init) */
 
-METHOD knh__FArray_new(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_new(Ctx *ctx, knh_sfp_t *sfp)
 {
 	FArray *o = (FArray*)sfp[0].o;
 	int init = IS_NULL(sfp[1].o) ? KNH_FARRAY_INITSIZE: p_int(sfp[1]);
@@ -218,7 +224,7 @@ METHOD knh__FArray_new(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method This! FArray.new:array(Int! n) */
 
-METHOD knh__FArray_new__array(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_new__array(Ctx *ctx, knh_sfp_t *sfp)
 {
 	FArray *o = (FArray*)sfp[0].o;
 	int init = p_int(sfp[1]);
@@ -232,7 +238,7 @@ METHOD knh__FArray_new__array(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS] This! FArray.new:init(Float! value) @VARARGS */
 
-METHOD knh__FArray_new__init(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_new__init(Ctx *ctx, knh_sfp_t *sfp)
 {
 	FArray *o = (FArray*)sfp[0].o;
 	knh_sfp_t *v = sfp + 1;
@@ -252,7 +258,7 @@ METHOD knh__FArray_new__init(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Array.add(Any1! value) */
 
-METHOD knh__Array_add(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_add(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	Array *o = (Array*)sfp[0].o;
@@ -269,7 +275,7 @@ METHOD knh__Array_add(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS] void Array.opLshift(Any1! v) */
 
-METHOD knh__Array_opLshift(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	Array *o = (Array*)sfp[0].o;
@@ -286,7 +292,7 @@ METHOD knh__Array_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void IArray.add(Int! value) */
 
-METHOD knh__IArray_add(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_add(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	IArray *o = (IArray*)sfp[0].o;
@@ -302,7 +308,7 @@ METHOD knh__IArray_add(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS] void IArray.opLshift(Int! v) */
 
-METHOD knh__IArray_opLshift(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	IArray *o = (IArray*)sfp[0].o;
@@ -318,7 +324,7 @@ METHOD knh__IArray_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void FArray.add(Float! value) */
 
-METHOD knh__FArray_add(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_add(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	FArray *o = (FArray*)sfp[0].o;
@@ -334,7 +340,7 @@ METHOD knh__FArray_add(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS] void FArray.opLshift(Float! v) */
 
-METHOD knh__FArray_opLshift(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	FArray *o = (FArray*)sfp[0].o;
@@ -349,10 +355,10 @@ METHOD knh__FArray_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 
 /* ======================================================================== */
 /* @method Int! Array.opSize() */
-/* @method Int! IArray.opSize() @alias=knh__Array_opSize */
-/* @method Int! FArray.opSize() @alias=knh__Array_opSize */
+/* @method Int! IArray.opSize() */
+/* @method Int! FArray.opSize() */
 
-METHOD knh__Array_opSize(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_opSize(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	KNH_RETURN_Int(ctx, sfp, o->size);
@@ -361,7 +367,7 @@ METHOD knh__Array_opSize(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Any1! Array.get(Int! n) */
 
-METHOD knh__Array_get(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_get(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	size_t n2 = knh_array_index(ctx, p_int(sfp[1]), o->size);
@@ -371,7 +377,7 @@ METHOD knh__Array_get(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Int! IArray.get(Int! n) */
 
-METHOD knh__IArray_get(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_get(Ctx *ctx, knh_sfp_t *sfp)
 {
 	IArray *o = (IArray*)sfp[0].o;
 	size_t n2 = knh_array_index(ctx, p_int(sfp[1]), o->size);
@@ -381,7 +387,7 @@ METHOD knh__IArray_get(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Float! FArray.get(Int! n) */
 
-METHOD knh__FArray_get(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_get(Ctx *ctx, knh_sfp_t *sfp)
 {
 	FArray *o = (FArray*)sfp[0].o;
 	size_t n2 = knh_array_index(ctx, p_int(sfp[1]), o->size);
@@ -391,7 +397,7 @@ METHOD knh__FArray_get(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Array.set(Int! n, Any1! v) */
 
-METHOD knh__Array_set(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_set(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	Array *o = (Array*)sfp[0].o;
@@ -405,7 +411,7 @@ METHOD knh__Array_set(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void IArray.set(Int! n, Int! v) */
 
-METHOD knh__IArray_set(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_set(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	IArray *o = (IArray*)sfp[0].o;
@@ -418,7 +424,7 @@ METHOD knh__IArray_set(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void FArray.set(Int! n, Float! v) */
 
-METHOD knh__FArray_set(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_set(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	FArray *o = (FArray*)sfp[0].o;
@@ -431,7 +437,7 @@ METHOD knh__FArray_set(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Array.setAll(Any1 v) */
 
-METHOD knh__Array_setAll(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_setAll(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	Array *o = (Array*)sfp[0].o;
@@ -472,7 +478,7 @@ Array *new_Array__subset(Ctx *ctx, Array *a, size_t s, size_t e)
 /* ------------------------------------------------------------------------ */
 /* @method This! Array.opSubset(Int s, Int e) @Debug */
 
-METHOD knh__Array_opSubset(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_opSubset(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	size_t s = IS_NULL(sfp[1].o) ? 0 : knh_array_index(ctx, p_int(sfp[1]), o->size);
@@ -483,7 +489,7 @@ METHOD knh__Array_opSubset(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method This! Array.opSubsete(Int s, Int e) @Debug */
 
-METHOD knh__Array_opSubsete(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_opSubsete(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	size_t s = IS_NULL(sfp[1].o) ? 0 : knh_array_index(ctx, p_int(sfp[1]), o->size);
@@ -494,7 +500,7 @@ METHOD knh__Array_opSubsete(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method This! Array.opOffset(Int s, Int offset) @Debug */
 
-METHOD knh__Array_opOffset(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_opOffset(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	size_t s = IS_NULL(sfp[1].o) ? 0 : knh_array_index(ctx, p_int(sfp[1]), o->size);
@@ -508,7 +514,7 @@ METHOD knh__Array_opOffset(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Array.insert(Int! n, Any1 v) */
 
-METHOD knh__Array_insert(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_insert(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	if(!knh_Object_isImmutable(o)) {
@@ -531,7 +537,7 @@ METHOD knh__Array_insert(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Array.remove(Int! n) */
 
-METHOD knh__Array_remove(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_remove(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	if(!knh_Object_isImmutable(o)) {
@@ -544,7 +550,7 @@ METHOD knh__Array_remove(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Any1 Array.pop() */
 
-METHOD knh__Array_pop(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_pop(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	if(!knh_Object_isImmutable(o) && o->size > 0) {
@@ -572,7 +578,7 @@ void knh_Array_clear(Ctx *ctx, Array *o)
 /* ------------------------------------------------------------------------ */
 /* @method Int! Array.indexOf(Any1 v) */
 
-METHOD knh__Array_indexOf(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_indexOf(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	knh_sfp_boxing(ctx, sfp + 1);
@@ -588,7 +594,7 @@ METHOD knh__Array_indexOf(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Int! Array.lastIndexOf(Any1 v) */
 
-METHOD knh__Array_lastIndexOf(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_lastIndexOf(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	knh_sfp_boxing(ctx, sfp + 1);
@@ -604,7 +610,7 @@ METHOD knh__Array_lastIndexOf(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Boolean! Array.opHas(Any1 v) */
 
-METHOD knh__Array_opHas(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_opHas(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	knh_sfp_boxing(ctx, sfp + 1);
@@ -621,9 +627,9 @@ METHOD knh__Array_opHas(Ctx *ctx, knh_sfp_t *sfp)
 /* [Collections] */
 
 /* ------------------------------------------------------------------------ */
-/* @ method void Array.sort(int(Any1!, Any1!)) */
+/* @method void Array.sort(ArrayCmp f) */
 
-METHOD knh__Array_sort(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_sort(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	TODO_THROW(ctx);
@@ -636,7 +642,7 @@ METHOD knh__Array_sort(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Array.reverse() */
 
-METHOD knh__Array_reverse(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_reverse(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	Array *o = (Array*)sfp[0].o;
@@ -654,7 +660,7 @@ METHOD knh__Array_reverse(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Array.swap(Int! m, Int! n) */
 
-METHOD knh__Array_swap(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_swap(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	Array *o = (Array*)sfp[0].o;
@@ -670,7 +676,7 @@ METHOD knh__Array_swap(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Array.shuffle() */
 
-METHOD knh__Array_shuffle(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_shuffle(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	Array *o = (Array*)sfp[0].o;
@@ -701,7 +707,7 @@ static int qsort_icmp(const void* ap, const void* bp)
 /* ------------------------------------------------------------------------ */
 /* @method void IArray.sort() */
 
-METHOD knh__IArray_sort(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_sort(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	IArray *o = (IArray*)sfp[0].o;
@@ -713,7 +719,7 @@ METHOD knh__IArray_sort(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void IArray.reverse() */
 
-METHOD knh__IArray_reverse(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_reverse(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	IArray *o = (IArray*)sfp[0].o;
@@ -731,7 +737,7 @@ METHOD knh__IArray_reverse(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void IArray.swap(Int! m, Int! n) */
 
-METHOD knh__IArray_swap(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_swap(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	IArray *o = (IArray*)sfp[0].o;
@@ -747,7 +753,7 @@ METHOD knh__IArray_swap(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void IArray.shuffle() */
 
-METHOD knh__IArray_shuffle(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_shuffle(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	IArray *o = (IArray*)sfp[0].o;
@@ -779,7 +785,7 @@ static int qsort_fcmp(const void* ap, const void* bp)
 /* ------------------------------------------------------------------------ */
 /* @method void FArray.sort() */
 
-METHOD knh__FArray_sort(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_sort(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	FArray *o = (FArray*)sfp[0].o;
@@ -791,7 +797,7 @@ METHOD knh__FArray_sort(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void FArray.reverse() */
 
-METHOD knh__FArray_reverse(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_reverse(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	FArray *o = (FArray*)sfp[0].o;
@@ -809,7 +815,7 @@ METHOD knh__FArray_reverse(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void FArray.swap(Int! m, Int! n) */
 
-METHOD knh__FArray_swap(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_swap(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	FArray *o = (FArray*)sfp[0].o;
@@ -825,7 +831,7 @@ METHOD knh__FArray_swap(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void FArray.shuffle() */
 
-METHOD knh__FArray_shuffle(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_shuffle(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	FArray *o = (FArray*)sfp[0].o;
@@ -891,7 +897,7 @@ MAPPER knh_Array_Iterator(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Any1.. Array.opItr() */
 
-METHOD knh__Array_opItr(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_opItr(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	KNH_RETURN(ctx, sfp, new_Iterator(ctx, ctx->tClass[o->h.cid].p1, UP(o), knh_Array_var_next));
@@ -985,7 +991,7 @@ void knh_ArrayDim_init(Ctx *ctx, Array *a, size_t x, size_t y, size_t z)
 /* ------------------------------------------------------------------------ */
 /* @method This! Array.new:array2D(Int! x, Int! y) @Private */
 
-METHOD knh__Array_new__array2D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_new__array2D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_ArrayDim_init(ctx, (Array*)sfp[0].o, p_size(sfp[1]), p_size(sfp[2]), 1);
 	KNH_RETURN(ctx, sfp, sfp[0].o);
@@ -994,7 +1000,7 @@ METHOD knh__Array_new__array2D(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method This! Array.new:array3D(Int! x, Int! y, Int! z) @Private */
 
-METHOD knh__Array_new__array3D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_new__array3D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_ArrayDim_init(ctx, (Array*)sfp[0].o, p_size(sfp[1]), p_size(sfp[2]), p_size(sfp[3]));
 	KNH_RETURN(ctx, sfp, sfp[0].o);
@@ -1003,7 +1009,7 @@ METHOD knh__Array_new__array3D(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Any1 Array.get2D(Int! x, Int! y) */
 
-METHOD knh__Array_get2D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_get2D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	knh_darray_t *d = ((knh_darray_t*)o->list) - 1;
@@ -1015,7 +1021,7 @@ METHOD knh__Array_get2D(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Any1 Array.get3D(Int! x, Int! y, Int! z) */
 
-METHOD knh__Array_get3D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_get3D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Array *o = (Array*)sfp[0].o;
 	knh_darray_t *d = ((knh_darray_t*)o->list) - 1;
@@ -1028,7 +1034,7 @@ METHOD knh__Array_get3D(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Array.set2D(Int! x, Int! y, Any1 v) */
 
-METHOD knh__Array_set2D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_set2D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	Array *o = (Array*)sfp[0].o;
@@ -1044,7 +1050,7 @@ METHOD knh__Array_set2D(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Array.set3D(Int! x, Int! y, Int! z, Any1 v) */
 
-METHOD knh__Array_set3D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Array_set3D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	Array *o = (Array*)sfp[0].o;
@@ -1077,7 +1083,7 @@ void knh_IArrayDim_init(Ctx *ctx, IArray *a, size_t x, size_t y, size_t z)
 /* ------------------------------------------------------------------------ */
 /* @method This! IArray.new:array2D(Int! x, Int! y) @Private */
 
-METHOD knh__IArray_new__array2D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_new__array2D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_IArrayDim_init(ctx, (IArray*)sfp[0].o, p_size(sfp[1]), p_size(sfp[2]), 1);
 	KNH_RETURN(ctx, sfp, sfp[0].o);
@@ -1086,7 +1092,7 @@ METHOD knh__IArray_new__array2D(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method This! IArray.new:array3D(Int! x, Int! y, Int! z) @Private */
 
-METHOD knh__IArray_new__array3D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_new__array3D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_IArrayDim_init(ctx, (IArray*)sfp[0].o, p_size(sfp[1]), p_size(sfp[2]), p_size(sfp[3]));
 	KNH_RETURN(ctx, sfp, sfp[0].o);
@@ -1095,7 +1101,7 @@ METHOD knh__IArray_new__array3D(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Int! IArray.get2D(Int! x, Int! y) */
 
-METHOD knh__IArray_get2D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_get2D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	IArray *o = (IArray*)sfp[0].o;
 	knh_darray_t *d = ((knh_darray_t*)o->ilist) - 1;
@@ -1107,7 +1113,7 @@ METHOD knh__IArray_get2D(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Int! IArray.get3D(Int! x, Int! y, Int! z) */
 
-METHOD knh__IArray_get3D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_get3D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	IArray *o = (IArray*)sfp[0].o;
 	knh_darray_t *d = ((knh_darray_t*)o->ilist) - 1;
@@ -1120,7 +1126,7 @@ METHOD knh__IArray_get3D(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void IArray.set2D(Int! x, Int! y, Int! v) */
 
-METHOD knh__IArray_set2D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_set2D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	IArray *o = (IArray*)sfp[0].o;
@@ -1135,7 +1141,7 @@ METHOD knh__IArray_set2D(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void IArray.set3D(Int! x, Int! y, Int! z, Int! v) */
 
-METHOD knh__IArray_set3D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__IArray_set3D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	IArray *o = (IArray*)sfp[0].o;
@@ -1167,7 +1173,7 @@ void knh_FArrayDim_init(Ctx *ctx, FArray *a, size_t x, size_t y, size_t z)
 /* ------------------------------------------------------------------------ */
 /* @method This! FArray.new:array2D(Int! x, Int! y) @Private */
 
-METHOD knh__FArray_new__array2D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_new__array2D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_FArrayDim_init(ctx, (FArray*)sfp[0].o, p_size(sfp[1]), p_size(sfp[2]), 1);
 	KNH_RETURN(ctx, sfp, sfp[0].o);
@@ -1176,7 +1182,7 @@ METHOD knh__FArray_new__array2D(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method This! FArray.new:array3D(Int! x, Int! y, Int! z) @Private */
 
-METHOD knh__FArray_new__array3D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_new__array3D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_FArrayDim_init(ctx, (FArray*)sfp[0].o, p_size(sfp[1]), p_size(sfp[2]), p_size(sfp[3]));
 	KNH_RETURN(ctx, sfp, sfp[0].o);
@@ -1185,7 +1191,7 @@ METHOD knh__FArray_new__array3D(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Float! FArray.get2D(Int! x, Int! y) */
 
-METHOD knh__FArray_get2D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_get2D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	FArray *o = (FArray*)sfp[0].o;
 	knh_darray_t *d = ((knh_darray_t*)o->flist) - 1;
@@ -1197,7 +1203,7 @@ METHOD knh__FArray_get2D(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Float! FArray.get3D(Int! x, Int! y, Int! z) */
 
-METHOD knh__FArray_get3D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_get3D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	FArray *o = (FArray*)sfp[0].o;
 	knh_darray_t *d = ((knh_darray_t*)o->flist) - 1;
@@ -1210,7 +1216,7 @@ METHOD knh__FArray_get3D(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void FArray.set2D(Int! x, Int! y, Float! v) */
 
-METHOD knh__FArray_set2D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_set2D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	FArray *o = (FArray*)sfp[0].o;
@@ -1225,7 +1231,7 @@ METHOD knh__FArray_set2D(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void FArray.set3D(Int! x, Int! y, Int! z, Float! v) */
 
-METHOD knh__FArray_set3D(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__FArray_set3D(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	FArray *o = (FArray*)sfp[0].o;
@@ -1239,6 +1245,54 @@ METHOD knh__FArray_set3D(Ctx *ctx, knh_sfp_t *sfp)
 }
 
 /* ------------------------------------------------------------------------ */
+/* [Iterator] */
+
+/* ------------------------------------------------------------------------ */
+/* @method void Iterator.%k(OutputStream w, String m) */
+
+void knh_Iterator__k(Ctx *ctx, Iterator *o, OutputStream *w, String *m)
+{
+	knh_putc(ctx, w, '[');
+	size_t c = 0;
+	knh_sfp_t *lsfp = KNH_LOCAL(ctx);
+	KNH_MOV(ctx, lsfp[0].o, o);
+	o->fnext_1(ctx, lsfp, 1);
+	while(HAS_ITRNEXT(lsfp[1].o)) {
+		if(c > 0) {
+			knh_write_delim(ctx,w);
+		}
+		knh_sfp_format(ctx, lsfp+1, METHODN__k, w, KNH_NULL);
+		c++;
+		o->fnext_1(ctx, lsfp, 1);
+	}
+	knh_putc(ctx, w, ']');
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method void Iterator.%dump(OutputStream w, String m) */
+
+void knh_Iterator__dump(Ctx *ctx, Iterator *o, OutputStream *w, String *m)
+{
+	knh_putc(ctx, w, '[');
+	size_t c = 0;
+	knh_sfp_t *lsfp = KNH_LOCAL(ctx);
+	KNH_MOV(ctx, lsfp[0].o, o);
+	o->fnext_1(ctx, lsfp, 1);
+	while(HAS_ITRNEXT(lsfp[1].o)) {
+		if(c > 0) {
+			knh_write_delim(ctx,w);
+		}
+		knh_sfp_format(ctx, lsfp+1, METHODN__k, w, KNH_NULL);
+		c++;
+		o->fnext_1(ctx, lsfp, 1);
+	}
+	knh_putc(ctx, w, ']');
+}
+
+/* ------------------------------------------------------------------------ */
+
+#endif/*KNH_CC_METHODAPI*/
+
 
 #ifdef __cplusplus
 }
