@@ -35,16 +35,18 @@
 extern "C" {
 #endif
 
+#ifdef KNH_CC_METHODAPI
+
 /* ======================================================================== */
 /* [DictMap] */
 
 /* ------------------------------------------------------------------------ */
 /* @method This! DictMap.new(Int n) */
 
-METHOD knh__DictMap_new(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictMap_new(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictMap *o = (DictMap*)sfp[0].o;
-	size_t init = IS_NULL(sfp[1].o) ? KNH_DICTMAP_INITSIZE: p_int(sfp[1]);
+	size_t init = IS_NULL(sfp[1].o) ? KNH_DICT_INITSIZE: p_int(sfp[1]);
 	if(init > 0) {
 		o->_list = knh_dictmap_malloc(ctx, init);
 		o->size = 0;
@@ -55,7 +57,7 @@ METHOD knh__DictMap_new(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS] This! DictMap.new:init(Any1 value) @VARARGS */
 
-METHOD knh__DictMap_new__init(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictMap_new__init(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictMap *o = (DictMap*)sfp[0].o;
 	knh_sfp_t *v = sfp + 1;
@@ -77,7 +79,7 @@ METHOD knh__DictMap_new__init(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Any1 DictMap.get(String! key) */
 
-METHOD knh__DictMap_get(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictMap_get(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN(ctx, sfp, knh_DictMap_get(ctx, (DictMap*)sfp[0].o, sfp[1].s));
 }
@@ -85,7 +87,7 @@ METHOD knh__DictMap_get(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Boolean! DictMap.opHas(String! key) */
 
-METHOD knh__DictMap_opHas(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictMap_opHas(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, knh_DictMap_index__b((DictMap*)sfp[0].o, knh_String_tobytes(sfp[1].s)) != -1);
 }
@@ -93,7 +95,7 @@ METHOD knh__DictMap_opHas(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void DictMap.set(String! key, Any1 value) */
 
-METHOD knh__DictMap_set(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictMap_set(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictMap *o = (DictMap*)sfp[0].o;
 	if(!knh_Object_isImmutable(o)) {
@@ -106,7 +108,7 @@ METHOD knh__DictMap_set(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void DictMap.remove(String! key) */
 
-METHOD knh__DictMap_remove(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictMap_remove(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictMap *o = (DictMap*)sfp[0].o;
 	if(!knh_Object_isImmutable(o)) {
@@ -118,7 +120,7 @@ METHOD knh__DictMap_remove(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void DictMap.clear() */
 
-METHOD knh__DictMap_clear(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictMap_clear(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictMap *o = (DictMap*)sfp[0].o;
 	if(!knh_Object_isImmutable(o)) {
@@ -130,7 +132,7 @@ METHOD knh__DictMap_clear(Ctx *ctx, knh_sfp_t *sfp)
 /* ======================================================================== */
 /* @method Int! DictMap.opSize() */
 
-METHOD knh__DictMap_opSize(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictMap_opSize(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Int(ctx, sfp, knh_DictMap_size((DictMap*)sfp[0].o));
 }
@@ -141,7 +143,7 @@ METHOD knh__DictMap_opSize(Ctx *ctx, knh_sfp_t *sfp)
 //#define OPSUBSETE  1
 //#define OPOFFSET   2
 //
-//METHOD knh__DictMap_subset(Ctx *ctx, knh_sfp_t *sfp, int mode)
+//static METHOD knh__DictMap_subset(Ctx *ctx, knh_sfp_t *sfp, int mode)
 //{
 //	DictMap *o = (DictMap*)sfp[0].o;
 //	size_t i, s = 0, e = o->size;
@@ -206,7 +208,7 @@ METHOD knh__DictMap_opSize(Ctx *ctx, knh_sfp_t *sfp)
 ///* ------------------------------------------------------------------------ */
 ///* @method This! DictMap.opSubsete(String s, String e) */
 //
-//METHOD knh__DictMap_opSubsete(Ctx *ctx, knh_sfp_t *sfp)
+//static METHOD knh__DictMap_opSubsete(Ctx *ctx, knh_sfp_t *sfp)
 //{
 //	knh__DictMap_subset(ctx, sfp, OPSUBSETE);
 //}
@@ -214,7 +216,7 @@ METHOD knh__DictMap_opSize(Ctx *ctx, knh_sfp_t *sfp)
 ///* ------------------------------------------------------------------------ */
 ///* @method This! DictMap.opSubset(String s, String e) */
 //
-//METHOD knh__DictMap_opSubset(Ctx *ctx, knh_sfp_t *sfp)
+//static METHOD knh__DictMap_opSubset(Ctx *ctx, knh_sfp_t *sfp)
 //{
 //	knh__DictMap_subset(ctx, sfp, OPSUBSET);
 //}
@@ -222,15 +224,14 @@ METHOD knh__DictMap_opSize(Ctx *ctx, knh_sfp_t *sfp)
 ///* ------------------------------------------------------------------------ */
 ///* @method This! DictMap.opOffset(String s, Int! n) */
 //
-//METHOD knh__DictMap_opOffset(Ctx *ctx, knh_sfp_t *sfp)
+//static METHOD knh__DictMap_opOffset(Ctx *ctx, knh_sfp_t *sfp)
 //{
 //	knh__DictMap_subset(ctx, sfp, OPOFFSET);
 //}
 
 /* ------------------------------------------------------------------------ */
 
-static
-String* knh_Object_key(Ctx *ctx, Object *o)
+static String* knh_Object_key(Ctx *ctx, Object *o)
 {
 	switch(o->h.bcid) {
 	case CLASS_String:
@@ -246,7 +247,7 @@ String* knh_Object_key(Ctx *ctx, Object *o)
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS] void DictMap.opLshift(Any v) @VARARGS */
 
-METHOD knh__DictMap_opLshift(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictMap_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictMap *o = (DictMap*)sfp[0].o;
 	if(!knh_Object_isImmutable(o)) {
@@ -271,8 +272,7 @@ METHOD knh__DictMap_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 /* ======================================================================== */
 /* [iterators] */
 
-static
-ITRNEXT knh_DictMap_key_next(Ctx *ctx, knh_sfp_t *sfp, int n)
+static ITRNEXT knh_DictMap_key_next(Ctx *ctx, knh_sfp_t *sfp, int n)
 {
 	Iterator *it = sfp[0].it;
 	DictMap *o = (DictMap*)DP(it)->source;
@@ -290,7 +290,7 @@ ITRNEXT knh_DictMap_key_next(Ctx *ctx, knh_sfp_t *sfp, int n)
 /* ------------------------------------------------------------------------ */
 /* @map DictMap Iterator! */
 
-MAPPER knh_DictMap_Iterator(Ctx *ctx, knh_sfp_t *sfp)
+static MAPPER knh_DictMap_Iterator(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_DictMap_sort((DictMap*)sfp[0].o);
 	KNH_MAPPED(ctx, sfp, new_Iterator(ctx, CLASS_String, sfp[0].o, knh_DictMap_key_next));
@@ -299,7 +299,7 @@ MAPPER knh_DictMap_Iterator(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @map DictMap String..! */
 
-MAPPER knh_DictMap_Iterator__(Ctx *ctx, knh_sfp_t *sfp)
+static MAPPER knh_DictMap_Iterator__(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_DictMap_sort((DictMap*)sfp[0].o);
 	KNH_MAPPED(ctx, sfp, new_Iterator(ctx, CLASS_String, sfp[0].o, knh_DictMap_key_next));
@@ -308,7 +308,7 @@ MAPPER knh_DictMap_Iterator__(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method String.. DictMap.opItr() */
 
-METHOD knh__DictMap_opItr(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictMap_opItr(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictMap *o = (DictMap*)sfp[0].o;
 	knh_DictMap_sort(o);
@@ -321,7 +321,7 @@ METHOD knh__DictMap_opItr(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void DictMap.%k(OutputStream w, String m) */
 
-void knh_DictMap__k(Ctx *ctx, DictMap *o, OutputStream *w, String *m)
+static void knh_DictMap__k(Ctx *ctx, DictMap *o, OutputStream *w, String *m)
 {
 	knh_DictMap_sort(o);
 	knh_putc(ctx, w, '{');
@@ -344,10 +344,10 @@ void knh_DictMap__k(Ctx *ctx, DictMap *o, OutputStream *w, String *m)
 /* ------------------------------------------------------------------------ */
 /* @method This! DictSet.new(Int n) */
 
-METHOD knh__DictSet_new(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictSet_new(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictSet *o = (DictSet*)sfp[0].o;
-	size_t init = IS_NULL(sfp[1].o) ? KNH_DICTMAP_INITSIZE: p_int(sfp[1]);
+	size_t init = IS_NULL(sfp[1].o) ? KNH_DICT_INITSIZE: p_int(sfp[1]);
 	if(init > 0) {
 		o->_list = knh_dictset_malloc(ctx, init);
 		o->size = 0;
@@ -361,7 +361,7 @@ METHOD knh__DictSet_new(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void DictSet.add(String! key) */
 
-METHOD knh__DictSet_add(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictSet_add(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictSet *o = (DictSet*)sfp[0].o;
 	if(!knh_Object_isImmutable(o)) {
@@ -373,7 +373,7 @@ METHOD knh__DictSet_add(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Int! DictSet.get(String! key) */
 
-METHOD knh__DictSet_get(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictSet_get(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Int(ctx, sfp, knh_DictSet_get(ctx, (DictSet*)sfp[0].o, sfp[1].s));
 }
@@ -381,7 +381,7 @@ METHOD knh__DictSet_get(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Boolean! DictSet.opHas(String! key) */
 
-METHOD knh__DictSet_opHas(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictSet_opHas(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, knh_DictSet_get__b((DictSet*)sfp[0].o, knh_String_tobytes(sfp[1].s)) != 0);
 }
@@ -389,7 +389,7 @@ METHOD knh__DictSet_opHas(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void DictSet.set(String! key, Int! value) */
 
-METHOD knh__DictSet_set(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictSet_set(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictSet *o = (DictSet*)sfp[0].o;
 	if(!knh_Object_isImmutable(o)) {
@@ -401,7 +401,7 @@ METHOD knh__DictSet_set(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void DictSet.remove(String! key) */
 
-METHOD knh__DictSet_remove(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictSet_remove(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictSet *o = (DictSet*)sfp[0].o;
 	if(!knh_Object_isImmutable(o)) {
@@ -413,7 +413,7 @@ METHOD knh__DictSet_remove(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void DictSet.clear() */
 
-METHOD knh__DictSet_clear(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictSet_clear(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictSet *o = (DictSet*)sfp[0].o;
 	if(!knh_Object_isImmutable(o)) {
@@ -425,7 +425,7 @@ METHOD knh__DictSet_clear(Ctx *ctx, knh_sfp_t *sfp)
 /* ======================================================================== */
 /* @method Int! DictSet.opSize() */
 
-METHOD knh__DictSet_opSize(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictSet_opSize(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Int(ctx, sfp, knh_DictSet_size((DictSet*)sfp[0].o));
 }
@@ -436,7 +436,7 @@ METHOD knh__DictSet_opSize(Ctx *ctx, knh_sfp_t *sfp)
 //#define OPSUBSETE  1
 //#define OPOFFSET   2
 //
-//METHOD knh__DictSet_subset(Ctx *ctx, knh_sfp_t *sfp, int mode)
+//static METHOD knh__DictSet_subset(Ctx *ctx, knh_sfp_t *sfp, int mode)
 //{
 //	DictSet *o = (DictSet*)sfp[0].o;
 //	size_t i, s = 0, e = o->size;
@@ -501,7 +501,7 @@ METHOD knh__DictSet_opSize(Ctx *ctx, knh_sfp_t *sfp)
 ///* ------------------------------------------------------------------------ */
 ///* @method This! DictSet.opSubsete(String s, String e) */
 //
-//METHOD knh__DictSet_opSubsete(Ctx *ctx, knh_sfp_t *sfp)
+//static METHOD knh__DictSet_opSubsete(Ctx *ctx, knh_sfp_t *sfp)
 //{
 //	knh__DictSet_subset(ctx, sfp, OPSUBSETE);
 //}
@@ -509,7 +509,7 @@ METHOD knh__DictSet_opSize(Ctx *ctx, knh_sfp_t *sfp)
 ///* ------------------------------------------------------------------------ */
 ///* @method This! DictSet.opSubset(String s, String e) */
 //
-//METHOD knh__DictSet_opSubset(Ctx *ctx, knh_sfp_t *sfp)
+//static METHOD knh__DictSet_opSubset(Ctx *ctx, knh_sfp_t *sfp)
 //{
 //	knh__DictSet_subset(ctx, sfp, OPSUBSET);
 //}
@@ -517,7 +517,7 @@ METHOD knh__DictSet_opSize(Ctx *ctx, knh_sfp_t *sfp)
 ///* ------------------------------------------------------------------------ */
 ///* @method This! DictSet.opOffset(String s, Int! n) */
 //
-//METHOD knh__DictSet_opOffset(Ctx *ctx, knh_sfp_t *sfp)
+//static METHOD knh__DictSet_opOffset(Ctx *ctx, knh_sfp_t *sfp)
 //{
 //	knh__DictSet_subset(ctx, sfp, OPOFFSET);
 //}
@@ -525,7 +525,7 @@ METHOD knh__DictSet_opSize(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS] void DictSet.opLshift(String v) @VARARGS */
 
-METHOD knh__DictSet_opLshift(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictSet_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictSet *o = (DictSet*)sfp[0].o;
 	if(!knh_Object_isImmutable(o)) {
@@ -545,7 +545,7 @@ METHOD knh__DictSet_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @map DictSet Iterator! @Const @Final */
 
-MAPPER knh_DictSet_Iterator(Ctx *ctx, knh_sfp_t *sfp)
+static MAPPER knh_DictSet_Iterator(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictSet *o = (DictSet*)sfp[0].o;
 	knh_DictSet_sort(o);
@@ -555,7 +555,7 @@ MAPPER knh_DictSet_Iterator(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @map DictSet String..! @Const @Final */
 
-MAPPER knh_DictSet_String__(Ctx *ctx, knh_sfp_t *sfp)
+static MAPPER knh_DictSet_String__(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictSet *o = (DictSet*)sfp[0].o;
 	knh_DictSet_sort(o);
@@ -565,7 +565,7 @@ MAPPER knh_DictSet_String__(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method String.. DictSet.opItr() */
 
-METHOD knh__DictSet_opItr(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__DictSet_opItr(Ctx *ctx, knh_sfp_t *sfp)
 {
 	DictSet *o = (DictSet*)sfp[0].o;
 	knh_DictSet_sort(o);
@@ -575,7 +575,7 @@ METHOD knh__DictSet_opItr(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @map String.. DictSet! @Final */
 
-MAPPER knh_String___DictSet(Ctx *ctx, knh_sfp_t *sfp)
+static MAPPER knh_String___DictSet(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Iterator *it = sfp[0].it;
 	DictSet *d = new_DictSet(ctx, 8);
@@ -593,7 +593,7 @@ MAPPER knh_String___DictSet(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void DictSet.%k(OutputStream w, String m) */
 
-void knh_DictSet__k(Ctx *ctx, DictSet *o, OutputStream *w, String *m)
+static void knh_DictSet__k(Ctx *ctx, DictSet *o, OutputStream *w, String *m)
 {
 	knh_DictSet_sort(o);
 	knh_putc(ctx, w, '{');
@@ -604,7 +604,7 @@ void knh_DictSet__k(Ctx *ctx, DictSet *o, OutputStream *w, String *m)
 		}
 		knh_write(ctx, w, knh_String_tobytes(o->list[c].key));
 //		knh_putc(ctx, w, ':');	knh_putc(ctx, w, ' ');
-//		knh_format(ctx, w, METHODN__k, o->list[c].value, KNH_NULL);
+//		knh_format(ctx, w, static METHODN__k, o->list[c].value, KNH_NULL);
 	}
 	knh_putc(ctx, w, '}');
 }
@@ -612,7 +612,7 @@ void knh_DictSet__k(Ctx *ctx, DictSet *o, OutputStream *w, String *m)
 /* ------------------------------------------------------------------------ */
 /* @method void DictSet.%dump(OutputStream w, String m) */
 
-void knh_DictSet__dump(Ctx *ctx, DictSet *o, OutputStream *w, String *m)
+static void knh_DictSet__dump(Ctx *ctx, DictSet *o, OutputStream *w, String *m)
 {
 	knh_DictSet_sort(o);
 	knh_putc(ctx, w, '{');
@@ -630,6 +630,8 @@ void knh_DictSet__dump(Ctx *ctx, DictSet *o, OutputStream *w, String *m)
 
 /* ------------------------------------------------------------------------ */
 
+#endif/*KNH_CC_METHODAPI*/
+
 #ifdef __cplusplus
 }
 #endif
