@@ -35,6 +35,8 @@
 extern "C" {
 #endif
 
+#ifdef KNH_CC_METHODAPI
+
 /* ======================================================================== */
 /* [common] */
 
@@ -63,10 +65,10 @@ int knh_stack_equals(Ctx *ctx, knh_sfp_t *sfp, Object *o)
 /* ------------------------------------------------------------------------ */
 /* @method This! HashMap.new(Int init) */
 
-METHOD knh__HashMap_new(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__HashMap_new(Ctx *ctx, knh_sfp_t *sfp)
 {
 	HashMap *o = (HashMap*)sfp[0].o;
-	int init = IS_NULL(sfp[1].o) ? KNH_HASHMAP_INITSIZE: p_int(sfp[1]);
+	int init = IS_NULL(sfp[1].o) ? KNH_HASH_INITSIZE: p_int(sfp[1]);
 	if(init > 0) {
 		ctx->tStruct[STRUCT_HashMap].finit(ctx, sfp[0].o, init);
 	}
@@ -76,7 +78,7 @@ METHOD knh__HashMap_new(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void HashMap.get(Any1 key) */
 
-METHOD knh__HashMap_get(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__HashMap_get(Ctx *ctx, knh_sfp_t *sfp)
 {
 	HashMap *o = (HashMap*)sfp[0].o;
 	knh_hcode_t hcode = knh_stack_hashCode(ctx, sfp + 1);
@@ -97,7 +99,7 @@ METHOD knh__HashMap_get(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Boolean! HashMap.opHas(Any1 key) */
 
-METHOD knh__HashMap_opHas(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__HashMap_opHas(Ctx *ctx, knh_sfp_t *sfp)
 {
 	HashMap *o = (HashMap*)sfp[0].o;
 	knh_hcode_t hcode = knh_stack_hashCode(ctx, sfp + 1);
@@ -118,7 +120,7 @@ METHOD knh__HashMap_opHas(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void HashMap.remove(Any1 key) */
 
-METHOD knh__HashMap_remove(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__HashMap_remove(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	knh_Hash_t *o = (knh_Hash_t*)sfp[0].o;
@@ -145,7 +147,7 @@ METHOD knh__HashMap_remove(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void HashMap.set(Any1! key, Any2 value) */
 
-METHOD knh__HashMap_set(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__HashMap_set(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	if(IS_NULL(sfp[2].o)) {
@@ -251,7 +253,7 @@ MAPPER knh_HashMap_Iterator(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Any1.. HashMap.opItr() */
 
-METHOD knh__HashMap_opItr(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__HashMap_opItr(Ctx *ctx, knh_sfp_t *sfp)
 {
 	HashMap *o = (HashMap*)sfp[0].o;
 	KNH_RETURN(ctx, sfp, new_Iterator(ctx, ctx->tClass[o->h.cid].p1, UP(o), knh_HashMap_var_next));
@@ -357,6 +359,8 @@ METHOD knh__HashMap_opItr(Ctx *ctx, knh_sfp_t *sfp)
 ///* ------------------------------------------------------------------------ */
 
 
+#endif/*KNH_CC_METHODAPI*/
+
 #ifdef __cplusplus
 }
 #endif
