@@ -35,24 +35,20 @@
 extern "C" {
 #endif
 
-/* ======================================================================== */
-/* [Boolean] */
+#ifdef KNH_CC_METHODAPI
 
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Boolean! Boolean.opNot() */
 
-_SS_ METHOD knh__Boolean_opNot(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Boolean_opNot(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, !(p_bool(sfp[0])));
 }
 
-/* ======================================================================== */
-/* [Int] */
-
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! Int.opAdd(Int! v) */
 
-_SS_ METHOD knh__Int_opAdd(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opAdd(Ctx *ctx, knh_sfp_t *sfp)
 {
 	//DBG2_P("<<%d + %d>>", (int)p_int(sfp[0]), (int)p_int(sfp[1]));
 	KNH_RETURN_Int(ctx, sfp, p_integer(sfp[0]) + p_integer(sfp[1]));
@@ -61,7 +57,7 @@ _SS_ METHOD knh__Int_opAdd(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! Int.opNeg() */
 
-_SS_ METHOD knh__Int_opNeg(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opNeg(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Int(ctx, sfp, -(p_integer(sfp[0])));
 }
@@ -69,7 +65,7 @@ _SS_ METHOD knh__Int_opNeg(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! Int.opSub(Int! n) */
 
-_SS_ METHOD knh__Int_opSub(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opSub(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Int(ctx, sfp, p_integer(sfp[0]) - p_integer(sfp[1]));
 }
@@ -77,7 +73,7 @@ _SS_ METHOD knh__Int_opSub(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! Int.opMul(Int! n) */
 
-_SS_ METHOD knh__Int_opMul(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opMul(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Int(ctx, sfp, p_integer(sfp[0]) * p_integer(sfp[1]));
 }
@@ -85,7 +81,7 @@ _SS_ METHOD knh__Int_opMul(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! Int.opDiv(Int! n) */
 
-_SS_ METHOD knh__Int_opDiv(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opDiv(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Int(ctx, sfp, p_integer(sfp[0]) / p_integer(sfp[1]));
 }
@@ -93,7 +89,7 @@ _SS_ METHOD knh__Int_opDiv(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! Int.opMod(Int! n) */
 
-_SS_ METHOD knh__Int_opMod(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opMod(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Int(ctx, sfp, p_integer(sfp[0]) % p_integer(sfp[1]));
 }
@@ -101,7 +97,7 @@ _SS_ METHOD knh__Int_opMod(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] Boolean! Int.opEq(Int! value) */
 
-_SS_ METHOD knh__Int_opEq(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opEq(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, p_integer(sfp[0]) == p_integer(sfp[1]));
 }
@@ -109,7 +105,7 @@ _SS_ METHOD knh__Int_opEq(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] Boolean! Int.opNeq(Int! value) */
 
-_SS_ METHOD knh__Int_opNeq(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opNeq(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, p_integer(sfp[0]) != p_integer(sfp[1]));
 }
@@ -117,7 +113,7 @@ _SS_ METHOD knh__Int_opNeq(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Boolean! Int.opLt(Int! value) */
 
-_SS_ METHOD knh__Int_opLt(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opLt(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, p_integer(sfp[0]) < p_integer(sfp[1]));
 }
@@ -125,7 +121,7 @@ _SS_ METHOD knh__Int_opLt(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Boolean! Int.opLte(Int! value) */
 
-_SS_ METHOD knh__Int_opLte(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opLte(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, p_integer(sfp[0]) <= p_integer(sfp[1]));
 }
@@ -133,7 +129,7 @@ _SS_ METHOD knh__Int_opLte(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Boolean! Int.opGt(Int! value) */
 
-_SS_ METHOD knh__Int_opGt(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opGt(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, p_integer(sfp[0]) > p_integer(sfp[1]));
 }
@@ -141,7 +137,7 @@ _SS_ METHOD knh__Int_opGt(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Boolean! Int.opGte(Int! value) */
 
-_SS_ METHOD knh__Int_opGte(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opGte(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, p_integer(sfp[0]) >= p_integer(sfp[1]));
 }
@@ -149,7 +145,7 @@ _SS_ METHOD knh__Int_opGte(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS|CONST] Int! Int.opLand(Int! v) */
 
-_SS_ METHOD knh__Int_opLand(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opLand(Ctx *ctx, knh_sfp_t *sfp)
 {
 	int ac = knh_sfp_argc(ctx, sfp + 1);
 	knh_sfp_t *v = sfp + 1;
@@ -164,7 +160,7 @@ _SS_ METHOD knh__Int_opLand(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS|CONST] Int! Int.opLor(Int! v) */
 
-_SS_ METHOD knh__Int_opLor(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opLor(Ctx *ctx, knh_sfp_t *sfp)
 {
 	int ac = knh_sfp_argc(ctx, sfp + 1);
 	knh_sfp_t *v = sfp + 1;
@@ -179,7 +175,7 @@ _SS_ METHOD knh__Int_opLor(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! Int.opXor(Int! n) */
 
-_SS_ METHOD knh__Int_opXor(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opXor(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Int(ctx, sfp, p_integer(sfp[0]) ^ p_integer(sfp[1]));
 }
@@ -187,7 +183,7 @@ _SS_ METHOD knh__Int_opXor(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! Int.opLnot() */
 
-_SS_ METHOD knh__Int_opLnot(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opLnot(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Int(ctx, sfp, ~(p_integer(sfp[0])));
 }
@@ -195,7 +191,7 @@ _SS_ METHOD knh__Int_opLnot(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! Int.opLshift(Int! n) */
 
-_SS_ METHOD knh__Int_opLshift(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Int(ctx, sfp, p_integer(sfp[0]) << p_integer(sfp[1]));
 }
@@ -203,7 +199,7 @@ _SS_ METHOD knh__Int_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! Int.opRshift(Int! n) */
 
-_SS_ METHOD knh__Int_opRshift(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opRshift(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Int(ctx, sfp, p_integer(sfp[0]) >> p_integer(sfp[1]));
 }
@@ -211,7 +207,7 @@ _SS_ METHOD knh__Int_opRshift(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! Int.opNext() */
 
-_SS_ METHOD knh__Int_opNext(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opNext(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Int(ctx, sfp, p_integer(sfp[0])+1);
 }
@@ -219,7 +215,7 @@ _SS_ METHOD knh__Int_opNext(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! Int.opPrev() */
 
-_SS_ METHOD knh__Int_opPrev(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opPrev(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Int(ctx, sfp, p_integer(sfp[0])-1);
 }
@@ -227,7 +223,7 @@ _SS_ METHOD knh__Int_opPrev(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[NULLBASE|CONST] Int! Int.opSize() */
 
-_SS_ METHOD knh__Int_opSize(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_opSize(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(IS_NULL(sfp[0].o)) {
 		KNH_RETURN_Int(ctx, sfp, 0);
@@ -246,7 +242,7 @@ _SS_ METHOD knh__Int_opSize(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[STATIC] Int! Int.random(Int n) */
 
-_SS_ METHOD knh__Int_random(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int_random(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_integer_t n = knh_rand();
 	if(IS_NOTNULL(sfp[1].o)) {
@@ -258,13 +254,10 @@ _SS_ METHOD knh__Int_random(Ctx *ctx, knh_sfp_t *sfp)
 	KNH_RETURN_Int(ctx, sfp, n);
 }
 
-/* ======================================================================== */
-/* [Float] */
-
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Float! Float.opAdd(Float! v) */
 
-_SS_ METHOD knh__Float_opAdd(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float_opAdd(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Float(ctx, sfp, p_float(sfp[0]) + p_float(sfp[1]));
 }
@@ -272,7 +265,7 @@ _SS_ METHOD knh__Float_opAdd(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Float! Float.opNeg() */
 
-_SS_ METHOD knh__Float_opNeg(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float_opNeg(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Float(ctx, sfp, -(p_float(sfp[0])));
 }
@@ -280,7 +273,7 @@ _SS_ METHOD knh__Float_opNeg(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Float! Float.opSub(Float! n) */
 
-_SS_ METHOD knh__Float_opSub(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float_opSub(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Float(ctx, sfp, p_float(sfp[0]) - p_float(sfp[1]));
 }
@@ -288,7 +281,7 @@ _SS_ METHOD knh__Float_opSub(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Float! Float.opMul(Float! n) */
 
-_SS_ METHOD knh__Float_opMul(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float_opMul(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Float(ctx, sfp, p_float(sfp[0]) * p_float(sfp[1]));
 }
@@ -296,7 +289,7 @@ _SS_ METHOD knh__Float_opMul(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Float! Float.opDiv(Float! n) */
 
-_SS_ METHOD knh__Float_opDiv(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float_opDiv(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Float(ctx, sfp, p_float(sfp[0]) / p_float(sfp[1]));
 }
@@ -304,7 +297,7 @@ _SS_ METHOD knh__Float_opDiv(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] Boolean! Float.opEq(Float value) */
 
-_SS_ METHOD knh__Float_opEq(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float_opEq(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, p_float(sfp[0]) == p_float(sfp[1]));
 }
@@ -312,7 +305,7 @@ _SS_ METHOD knh__Float_opEq(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] Boolean! Float.opNeq(Float value) */
 
-_SS_ METHOD knh__Float_opNeq(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float_opNeq(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, p_float(sfp[0]) != p_float(sfp[1]));
 }
@@ -320,7 +313,7 @@ _SS_ METHOD knh__Float_opNeq(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Boolean! Float.opLt(Float! value) */
 
-_SS_ METHOD knh__Float_opLt(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float_opLt(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, p_float(sfp[0]) < p_float(sfp[1]));
 }
@@ -328,7 +321,7 @@ _SS_ METHOD knh__Float_opLt(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Boolean! Float.opLte(Float! value) */
 
-_SS_ METHOD knh__Float_opLte(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float_opLte(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, p_float(sfp[0]) <= p_float(sfp[1]));
 }
@@ -336,7 +329,7 @@ _SS_ METHOD knh__Float_opLte(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Boolean! Float.opGt(Float! value) */
 
-_SS_ METHOD knh__Float_opGt(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float_opGt(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, p_float(sfp[0]) > p_float(sfp[1]));
 }
@@ -344,7 +337,7 @@ _SS_ METHOD knh__Float_opGt(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Boolean! Float.opGte(Float! value) */
 
-_SS_ METHOD knh__Float_opGte(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float_opGte(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, p_float(sfp[0]) >= p_float(sfp[1]));
 }
@@ -352,16 +345,15 @@ _SS_ METHOD knh__Float_opGte(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Float! Float.opNext() */
 
-_SS_ METHOD knh__Float_opNext(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float_opNext(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Float(ctx, sfp, (p_float(sfp[0]))+1.0);
 }
 
 /* ------------------------------------------------------------------------ */
-
 /* @method[CONST] Float! Float.opPrev() */
 
-_SS_ METHOD knh__Float_opPrev(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float_opPrev(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Float(ctx, sfp, (p_float(sfp[0]))-1.0);
 }
@@ -369,7 +361,7 @@ _SS_ METHOD knh__Float_opPrev(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[STATIC] Float! Float.random()  */
 
-_SS_ METHOD knh__Float_random(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float_random(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Float(ctx, sfp, knh_float_rand());
 }
@@ -377,7 +369,7 @@ _SS_ METHOD knh__Float_random(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[NULLBASE|CONST] Int! Float.opSize() */
 
-_SS_ METHOD knh__Float_opSize(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float_opSize(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(IS_NULL(sfp[0].o)) {
 		KNH_RETURN_Int(ctx, sfp, 0);
@@ -388,13 +380,10 @@ _SS_ METHOD knh__Float_opSize(Ctx *ctx, knh_sfp_t *sfp)
 	}
 }
 
-/* ======================================================================== */
-/* [Boolean] */
-
 /* ------------------------------------------------------------------------ */
 /* @method void Boolean.%s(OutputStream w, String m) */
 
-_SS_ METHOD knh__Boolean__s(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Boolean__s(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(p_bool(sfp[0])) {
 		knh_write(ctx, sfp[1].w, knh_String_tobytes(TS_true));
@@ -407,7 +396,7 @@ _SS_ METHOD knh__Boolean__s(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Boolean.%k(OutputStream w, String m) */
 
-_SS_ METHOD knh__Boolean__k(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Boolean__k(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(p_bool(sfp[0])) {
 		knh_write(ctx, sfp[1].w, knh_String_tobytes(TS_true));
@@ -417,11 +406,10 @@ _SS_ METHOD knh__Boolean__k(Ctx *ctx, knh_sfp_t *sfp)
 	}
 }
 
-/* ------------------------------------------------------------------------ */
 /* ------------------------------------------------------------------------ */
 /* @method void Int.%s(OutputStream w, String m) */
 
-_SS_ METHOD knh__Int__s(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int__s(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_write_integerfmt(ctx, sfp[1].w, KNH_INTEGER_FMT, sfp[0].ivalue);
 }
@@ -429,7 +417,7 @@ _SS_ METHOD knh__Int__s(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Int.%k(OutputStream w, String m) */
 
-_SS_ METHOD knh__Int__k(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int__k(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_write_integerfmt(ctx, sfp[1].w, KNH_INTEGER_FMT, sfp[0].ivalue);
 }
@@ -437,7 +425,7 @@ _SS_ METHOD knh__Int__k(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Int.%d(OutputStream w, String m) */
 
-_SS_ METHOD knh__Int__d(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int__d(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(IS_String(sfp[2].s)) {
 		char fmt[40];
@@ -452,7 +440,7 @@ _SS_ METHOD knh__Int__d(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Int.%u(OutputStream w, String m) */
 
-_SS_ METHOD knh__Int__u(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int__u(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(IS_String(sfp[2].s)) {
 		char fmt[40];
@@ -467,7 +455,7 @@ _SS_ METHOD knh__Int__u(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Int.%f(OutputStream w, String m) */
 
-_SS_ METHOD knh__Int__f(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int__f(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(IS_String(sfp[2].s)) {
 		char fmt[40];
@@ -482,7 +470,7 @@ _SS_ METHOD knh__Int__f(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Int.%x(OutputStream w, String m) */
 
-_SS_ METHOD knh__Int__x(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int__x(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_write_integerfmt(ctx, sfp[1].w, KNH_INTEGER_XFMT, sfp[0].ivalue);
 }
@@ -510,7 +498,7 @@ void knh_write_bits(Ctx *ctx, OutputStream *w, knh_uint64_t n, size_t bits)
 /* ------------------------------------------------------------------------ */
 /* @method void Int.%bits(OutputStream w, String m) */
 
-_SS_ METHOD knh__Int__bits(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Int__bits(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_write_bits(ctx, sfp[1].w, sfp[0].ivalue, sizeof(knh_integer_t) * 8);
 }
@@ -519,7 +507,7 @@ _SS_ METHOD knh__Int__bits(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Float.%s(OutputStream w, String m) */
 
-_SS_ METHOD knh__Float__s(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float__s(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_write__ffmt(ctx, sfp[1].w, KNH_FLOAT_FMT, p_float(sfp[0]));
 }
@@ -527,7 +515,7 @@ _SS_ METHOD knh__Float__s(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Float.%d(OutputStream w, String m) */
 
-_SS_ METHOD knh__Float__d(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float__d(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(IS_String(sfp[2].s)) {
 		char fmt[40];
@@ -543,7 +531,7 @@ _SS_ METHOD knh__Float__d(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Float.%f(OutputStream w, String m) */
 
-_SS_ METHOD knh__Float__f(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float__f(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(IS_String(sfp[2].s)) {
 		char fmt[40];
@@ -559,7 +547,7 @@ _SS_ METHOD knh__Float__f(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Float.%bits(OutputStream w, String m) */
 
-_SS_ METHOD knh__Float__bits(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float__bits(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_write_bits(ctx, sfp[1].w, sfp[0].data, sizeof(knh_float_t) * 8);
 }
@@ -567,7 +555,7 @@ _SS_ METHOD knh__Float__bits(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void Float.%k(OutputStream w, String m) */
 
-_SS_ METHOD knh__Float__k(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Float__k(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Float *o = sfp[0].f;
 	FloatUnit *u = (FloatUnit*)ctx->tClass[o->h.cid].cspec;
@@ -587,7 +575,7 @@ _SS_ METHOD knh__Float__k(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @map[CONST] Boolean String! @Const @Final @LossLess */
 
-_SS_ MAPPER knh_Boolean_String(Ctx *ctx, knh_sfp_t *sfp)
+static MAPPER knh_Boolean_String(Ctx *ctx, knh_sfp_t *sfp)
 {
 	String *s = (p_bool(sfp[0])) ? TS_true : TS_false;
 	KNH_MAPPED(ctx, sfp, s);
@@ -596,7 +584,7 @@ _SS_ MAPPER knh_Boolean_String(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @map[CONST] String Boolean! @Const @Final */
 
-_SS_ MAPPER knh_String_Boolean(Ctx *ctx, knh_sfp_t *sfp)
+static MAPPER knh_String_Boolean(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_bytes_t t = knh_String_tobytes(sfp[0].s);
 	int b = (knh_bytes_equalsIgnoreCase(t, STEXT("true")) ||
@@ -607,7 +595,7 @@ _SS_ MAPPER knh_String_Boolean(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @map String Int @Const @Final */
 
-_SS_ MAPPER knh_String_Int(Ctx *ctx, knh_sfp_t *sfp)
+static MAPPER knh_String_Int(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_integer_t v = 0;
 	if(knh_bytes_parseinteger(knh_String_tobytes(sfp[0].s), &v)) {
@@ -619,9 +607,9 @@ _SS_ MAPPER knh_String_Int(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @map Int String! @Const @Final @LossLess */
 
-_SS_ MAPPER knh_Int_String(Ctx *ctx, knh_sfp_t *sfp)
+static MAPPER knh_Int_String(Ctx *ctx, knh_sfp_t *sfp)
 {
-	char buf[KNH_INTUNIT_BUFSIZ];
+	char buf[256];
 	knh_snprintf(buf, sizeof(buf), KNH_INTEGER_FMT, sfp[0].ivalue);
 	KNH_MAPPED(ctx, sfp, new_String(ctx, B(buf), NULL));
 }
@@ -629,7 +617,7 @@ _SS_ MAPPER knh_Int_String(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @map String Float @Final @Const */
 
-_SS_ MAPPER knh_String_Float(Ctx *ctx, knh_sfp_t *sfp)
+static MAPPER knh_String_Float(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_float_t f = 0.0;
 	if(knh_bytes_parsefloat(knh_String_tobytes(sfp[0].s), &f)) {
@@ -643,9 +631,9 @@ _SS_ MAPPER knh_String_Float(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @map Float String! @Const @Final @LossLess */
 
-_SS_ MAPPER knh_Float_String(Ctx *ctx, knh_sfp_t *sfp)
+static MAPPER knh_Float_String(Ctx *ctx, knh_sfp_t *sfp)
 {
-	char buf[BUFSIZ_FLOAT];
+	char buf[256];
 	knh_snprintf(buf, sizeof(buf), KNH_FLOAT_FMT, sfp[0].fvalue);
 	KNH_MAPPED(ctx, sfp, new_String(ctx, B(buf), NULL));
 }
@@ -653,7 +641,7 @@ _SS_ MAPPER knh_Float_String(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @map Int Float! @Const @Final */
 
-_SS_ MAPPER knh_Int_Float(Ctx *ctx, knh_sfp_t *sfp)
+static MAPPER knh_Int_Float(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_float_t v = (knh_float_t)sfp[0].ivalue;
 	KNH_MAPPED_Float(ctx, sfp, v);
@@ -662,22 +650,17 @@ _SS_ MAPPER knh_Int_Float(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @map Float Int! @Const @Final */
 
-_SS_ MAPPER knh_Float_Int(Ctx *ctx, knh_sfp_t *sfp)
+static MAPPER knh_Float_Int(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_integer_t v = (knh_integer_t)sfp[0].fvalue;
 	KNH_MAPPED_Int(ctx, sfp, v);
 }
 
-/* ======================================================================== */
-/* [GEN] */
-
-void init_primitive(Ctx *ctx)
-{
-
-}
-
 /* ------------------------------------------------------------------------ */
 
+#endif /*KNH_CC_METHODAPI*/
+
+
 #ifdef __cplusplus
 }
 #endif
