@@ -498,7 +498,7 @@ void knh_Class__man(Ctx *ctx, Class *o, OutputStream *w, String *m)
 {
 	knh_class_t cid = (o)->cid;
 	knh_Class_NAME__man(ctx, cid, w);
-	knh_tConst__man(ctx, cid, w);
+	knh_Const__man(ctx, cid, w);
 
 	char bufmn[CLASSNAME_BUFSIZ];
 	KNH_ASSERT_cid(cid);
