@@ -208,6 +208,10 @@ char* knh_format_type(Ctx *ctx, char *buf, size_t bufsiz, knh_type_t type)
 		return buf;
 	}
 	knh_class_t cid = CLASS_type(type);
+	if(!(cid < ctx->share->tClassSize)) {
+		cid = CLASS_Any;
+		type = cid;
+	}
 	KNH_ASSERT_cid(cid);
 	char *cname = knh_tClass_CLASSN(ctx, cid);
 	if(type == NNTYPE_Int || type == NNTYPE_Float || type == NNTYPE_Boolean) {
