@@ -279,9 +279,16 @@ Closure* new_ClosureDEFAULT(Ctx *ctx, knh_type_t rtype, knh_class_t cid)
 
 /* ------------------------------------------------------------------------ */
 
-static
-void konoha_setClosure(Ctx *ctx, knh_class_t cid, String *name, knh_type_t r0, knh_type_t p1, knh_type_t p2, knh_type_t p3)
+knh_class_t
+konoha_addClosureClass(Ctx *ctx, knh_class_t cid, String *name, knh_type_t r0, knh_type_t p1, knh_type_t p2, knh_type_t p3)
 {
+	if(cid == CLASS_newid) {
+		cid = knh_tClass_newId(ctx);
+	}else {
+		if(!(cid < ctx->share->tClassSize)) {
+			ctx->share->tClassSize = cid + 1;
+		}
+	}
 	knh_tClass_t *TC = (knh_tClass_t*)(&ctx->tClass[cid]);
 	KNH_ASSERT(ctx->tClass[cid].class_cid == NULL);
 
@@ -304,6 +311,7 @@ void konoha_setClosure(Ctx *ctx, knh_class_t cid, String *name, knh_type_t r0, k
 	TC->p2 = p2;
 	TC->p3 = p3;
 	konoha_setClassDefaultValue(ctx, cid, UP(new_ClosureDEFAULT(ctx, r0, cid)), NULL);
+	return cid;
 }
 
 /* ------------------------------------------------------------------------ */
@@ -331,8 +339,7 @@ knh_class_t knh_class_Closure(Ctx *ctx, knh_type_t r0, knh_type_t p1, knh_type_t
 	knh_class_t cid = knh_NameSpace_getClass(ctx, knh_rootNameSpace, B(buf));
 	if(cid == CLASS_unknown) {
 		DBG2_P("*** Generating %s ***", buf);
-		cid = knh_tClass_newId(ctx);
-		konoha_setClosure(ctx, cid, new_String(ctx, B(buf), NULL), r0, p1, p2, p3);
+		konoha_addClosureClass(ctx, CLASS_newid, new_String(ctx, B(buf), NULL), r0, p1, p2, p3);
 	}
 	return cid;
 }
