@@ -35,49 +35,13 @@
 extern "C" {
 #endif
 
-
-///* ======================================================================== */
-///* [structs] */
-//
-//void
-//knh_DictIdx_struct_init(Ctx *ctx, knh_DictIdx_struct *b, int init, Object *cs)
-//{
-//	if(init == 0) init = KNH_DICTMAP_INITSIZE;
-//	b->offset = 0;
-//	if(ctx == NULL) {
-//		KNH_INITv(b->terms, new_Array0(ctx, init));
-//	}
-//	else {
-//		KNH_INITv(b->terms, new_Array(ctx, CLASS_String, init));
-//	}
-//	KNH_INITv(b->termsDictSet, new_DictSet(ctx, init));
-//}
-//
-///* ------------------------------------------------------------------------ */
-//
-//#define _knh_DictIdx_struct_copy   NULL
-//
-///* ------------------------------------------------------------------------ */
-//
-//void
-//knh_DictIdx_struct_traverse(Ctx *ctx, knh_DictIdx_struct *b, knh_ftraverse gc)
-//{
-//	gc(ctx, UP(b->terms));
-//	gc(ctx, UP(b->termsDictSet));
-//}
-
 /* ======================================================================== */
 /* [constructors] */
 
-DictIdx* new_DictIdx(Ctx *ctx, size_t init, knh_int_t offset)
+DictIdx* new_DictIdx0(Ctx *ctx, size_t init, knh_int_t offset)
 {
-	knh_DictIdx_t *o = (knh_DictIdx_t*)new_PObject0(ctx, FLAG_DictIdx, CLASS_DictIdx, CLASS_DictIdx);
-	if(ctx == NULL) {
-		KNH_INITv(o->terms, new_Array0(ctx, init));
-	}
-	else {
-		KNH_INITv(o->terms, new_Array(ctx, CLASS_String, init));
-	}
+	knh_DictIdx_t *o = (knh_DictIdx_t*)new_hObject(ctx, FLAG_DictIdx, CLASS_DictIdx, CLASS_DictIdx);
+	KNH_INITv(o->terms, new_Array0(ctx, init));
 	KNH_INITv(o->termsDictSet, new_DictSet(ctx, init));
 	o->offset = offset;
 	return o;
@@ -85,9 +49,9 @@ DictIdx* new_DictIdx(Ctx *ctx, size_t init, knh_int_t offset)
 
 /* ------------------------------------------------------------------------ */
 
-DictIdx* new_DictIdx__ignoreCase(Ctx *ctx, size_t init, knh_int_t offset)
+DictIdx* new_DictIdx0__ignoreCase(Ctx *ctx, size_t init, knh_int_t offset)
 {
-	DictIdx *o = new_DictIdx(ctx, init, offset);
+	DictIdx *o = new_DictIdx0(ctx, init, offset);
 	knh_DictSet_toIgnoreCase(o->termsDictSet);
 	return o;
 }
@@ -171,7 +135,7 @@ String* knh_DictIdx_get__fast(DictIdx *o, knh_int_t termid)
 /* ------------------------------------------------------------------------ */
 /* @  method String DictIdx.get(Int! index) */
 
-String* knh_DictIdx_get(DictIdx *o, knh_int_t termid)
+String* knh_DictIdx_get(Ctx *ctx, DictIdx *o, knh_int_t termid)
 {
 	size_t n = termid_toarrayn(termid);
 	if(0 <= n && n < knh_Array_size(o->terms)) {
