@@ -35,54 +35,34 @@
 extern "C" {
 #endif
 
-/* ======================================================================== */
-/* [structs] */
-
-void
-knh_InputStream_struct_init(Ctx *ctx, knh_InputStream_struct *b, int init, Object *cs)
-{
-	b->fd = -1;
-	KNH_INITv(b->ba, KNH_NULL);
-	b->buf = "";
-	b->bufpos = 0;
-	b->bufend = 0;
-	b->bufsiz = 0;
-	b->driver = knh_System_getDefaultIODriver();
-	KNH_INITv(b->bconv, KNH_NULL);
-	KNH_INITv(b->enc, TS_ENCODING);
-	KNH_INITv(b->urn, TS_DEVNULL);
-	b->size    = 0;
-	b->line    = 1;
-	b->prev    = '\n';
-	b->fileid   = 0;
-}
-
-/* ------------------------------------------------------------------------ */
-
-#define _knh_InputStream_struct_copy   NULL
-
-/* ------------------------------------------------------------------------ */
-
-#define _knh_InputStream_struct_compare  NULL
-
-/* ------------------------------------------------------------------------ */
-
-void
-knh_InputStream_struct_traverse(Ctx *ctx, knh_InputStream_struct *b, knh_ftraverse ftr)
-{
-	if(IS_SWEEP(ftr) && b->fd != -1) {
-		b->driver.fclose(ctx, b->fd);
-		b->fd = -1;
-	}
-	ftr(ctx, UP(b->ba));
-	ftr(ctx, UP(b->enc));
-	ftr(ctx, UP(b->bconv));
-	ftr(ctx, UP(b->urn));
-}
-
 /* ======================================================================== */
 /* [methods] */
 
+//static
+//void knh_InputStream_setbuf(Ctx *ctx, InputStream *in)
+//{
+//	KNH_ASSERT(!IS_Bytes(DP(in)->ba));
+//	if(DP(o)->fd != -1) {
+//		DP(o)->bufsiz = DP(o)->driver.bufsiz;
+//		if(DP(o)->bufsiz > 0) {
+//			KNH_SETv(ctx, DP(o)->ba, new_Bytes(ctx, DP(o)->bufsiz));
+//			DP(o)->buf = (char*)(DP(o)->ba)->buf;
+//		}
+//		DP(o)->bufpos = 0;
+//		DP(o)->bufend = 0;  /* empty */
+//		KNH_SETv(ctx, DP(o)->urn, new_String(ctx, fname, NULL));
+//	}
+//	else {
+//		DP(o)->driver = knh_System_getDefaultIODriver();
+//		char buff[FILENAME_BUFSIZ];
+//		knh_snprintf(buff, sizeof(buff), "IO!!: '%s'", (char*)fname.buf);
+//		return (Object*)new_Nue__s(ctx, buff);
+//	}
+//}
+
+/* ------------------------------------------------------------------------ */
+
+
 Object *knh_InputStream_open(Ctx *ctx, InputStream *o, String *urn)
 {
 	knh_bytes_t fname = knh_String_tobytes(urn);
@@ -182,19 +162,19 @@ knh_InputStream_read(Ctx *ctx, InputStream *o, char *buf, size_t bufsiz)
 String* knh_InputStream_readLine(Ctx *ctx, InputStream *o)
 {
 	int ch;
-	knh_wbuf_t cb = knh_Context_wbuf(ctx);
+	knh_cwb_t cwb = new_cwb(ctx);
 	while((ch = knh_InputStream_getc(ctx, o)) != EOF) {
 		if(ch == '\r') {
-			return new_String__wbufconv(ctx, cb, DP(o)->bconv);
+			return new_String__cwbconv(ctx, cwb, DP(o)->bconv);
 		}
 		if(ch == '\n') {
 			if(DP(o)->prev == '\r') continue;
-			return new_String__wbufconv(ctx, cb, DP(o)->bconv);
+			return new_String__cwbconv(ctx, cwb, DP(o)->bconv);
 		}
-		knh_Bytes_putc(ctx, cb.ba, ch);
+		knh_Bytes_putc(ctx, cwb.ba, ch);
 	}
-	if(knh_wbuf_size(cb) != 0) {
-		return new_String__wbufconv(ctx, cb, DP(o)->bconv);
+	if(knh_cwb_size(cwb) != 0) {
+		return new_String__cwbconv(ctx, cwb, DP(o)->bconv);
 	}
 	return (String*)KNH_NULL;
 }
@@ -223,33 +203,12 @@ int knh_InputStream_isClosed(InputStream *o)
 	return (DP(o)->fd == -1);
 }
 
-/* ======================================================================== */
-/* [Bytes] */
-
-InputStream *new_InputStream__stdio(Ctx *ctx, FILE *fp)
-{
-	InputStream* o =
-		(InputStream*)new_Object_malloc(ctx, FLAG_InputStream, CLASS_InputStream, sizeof(knh_InputStream_struct));
-	knh_InputStream_struct_init(ctx, DP(o), 0, NULL);
-	KNH_ASSERT(fp == stdin);
-	DP(o)->driver = knh_System_getDefaultIODriver();
-	knh_InputStream_setSTDIN(o, 1);
-	KNH_SETv(ctx, DP(o)->urn, TS_DEVSTDIN);
-	DP(o)->fp = fp;
-	DP(o)->bufsiz = 0;
-	DP(o)->bufpos = 0;
-	DP(o)->bufend = 0;  /* empty */
-	return o;
-}
-
 /* ======================================================================== */
 /* [File] */
 
 KNHAPI(InputStream*) new_FileInputStream(Ctx *ctx, knh_bytes_t file)
 {
-	InputStream* o =
-		(InputStream*)new_Object_malloc(ctx, FLAG_InputStream, CLASS_InputStream, sizeof(knh_InputStream_struct));
-	knh_InputStream_struct_init(ctx, DP(o), 0, NULL);
+	InputStream* o = (InputStream*)new_Object_bcid(ctx, CLASS_InputStream, 0);
 	DP(o)->driver = *(knh_System_getIODriver(ctx, STEXT("file")));
 	DP(o)->fd = DP(o)->driver.fopen(ctx, o, NULL, file, "r");
 	if(DP(o)->fd != -1) {
@@ -273,9 +232,7 @@ KNHAPI(InputStream*) new_FileInputStream(Ctx *ctx, knh_bytes_t file)
 
 KNHAPI(InputStream*) new_BytesInputStream(Ctx *ctx, Bytes *ba, size_t s, size_t e)
 {
-	InputStream* o =
-		(InputStream*)new_Object_malloc(ctx, FLAG_InputStream, CLASS_InputStream, sizeof(knh_InputStream_struct));
-	knh_InputStream_struct_init(ctx, DP(o), 0, NULL);
+	InputStream* o = (InputStream*)new_Object_bcid(ctx, CLASS_InputStream, 0);
 	DP(o)->fd = -1;
 	KNH_ASSERT(IS_Bytes(ba));
 	KNH_SETv(ctx, DP(o)->ba, ba);
@@ -302,9 +259,7 @@ MAPPER knh_Bytes_InputStream(Ctx *ctx, knh_sfp_t *sfp)
 
 KNHAPI(InputStream*) new_StringInputStream(Ctx *ctx, String *str, size_t s, size_t e)
 {
-	InputStream* o =
-		(InputStream*)new_Object_malloc(ctx, FLAG_InputStream, CLASS_InputStream, sizeof(knh_InputStream_struct));
-	knh_InputStream_struct_init(ctx, DP(o), 0, NULL);
+	InputStream* o = (InputStream*)new_Object_bcid(ctx, CLASS_InputStream, 0);
 	DP(o)->fd = -1;
 	KNH_ASSERT(IS_Bytes(str));
 	KNH_SETv(ctx, DP(o)->str, str);
