@@ -302,7 +302,7 @@ int knh_methodn_isNew(Ctx *ctx, knh_methodn_t mn)
 
 /* ------------------------------------------------------------------------ */
 
-int knh_Method_isNew(Ctx *ctx, Method *o)
+int knh_Method_isConstructor(Ctx *ctx, Method *o)
 {
 	knh_class_t rtype = CLASS_type(knh_Method_rztype(o));
 	if(rtype != DP(o)->cid) {
