@@ -179,8 +179,7 @@ char* knh_Context_CLASSN(Ctx *ctx, knh_class_t cid)
 
 /* ------------------------------------------------------------------------ */
 
-void
-knh_NameSpace_import(Ctx *ctx, NameSpace *o, knh_bytes_t p)
+void knh_NameSpace_import(Ctx *ctx, NameSpace *o, knh_bytes_t p)
 {
 	size_t i;
 	if(p.buf[p.len-1] == '.') {
@@ -316,7 +315,7 @@ knh_NameSpace_existsConst(Ctx *ctx, NameSpace *o, knh_bytes_t name)
 		}
 		return 0;
 	}
-	return knh_tConst_exists(ctx, name);
+	return konoha_existsConst(ctx, name);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -332,7 +331,7 @@ void knh_NameSpace_addConst(Ctx *ctx, NameSpace *o, String *name, Object *value)
 		knh_DictMap_set(ctx, DP(o)->lconstDictMap, name, value);
 	}
 	else {
-		knh_tConst_addGlobalConst(ctx, name, value);
+		konoha_addConst(ctx, name, value);
 	}
 }
 
@@ -348,35 +347,9 @@ knh_NameSpace_getConst(Ctx *ctx, NameSpace *o, knh_bytes_t name)
 		}
 		return (Object*)KNH_NULL;
 	}
-	return knh_tConst_value(ctx, name);
+	return konoha_getConst(ctx, name);
 }
 
-/* ======================================================================== */
-/* [loaded] */
-
-void knh_NameSpace_loaded(Ctx *ctx, NameSpace *o, knh_fileid_t fileid)
-{
-	KNH_ASSERT(IS_NameSpace(o));
-	if(IS_NULL(DP(o)->lconstDictMap)) {
-		KNH_SETv(ctx, DP(o)->lconstDictMap, new_DictMap0(ctx, 16));
-	}
-	char buf[80];
-	knh_snprintf(buf, sizeof(buf), "_LOADED_%d", (int)fileid);
-	knh_DictMap_set(ctx, DP(o)->lconstDictMap, new_String(ctx, B(buf), NULL), UP(knh_tfileid_name(ctx, fileid)));
-}
-
-/* ------------------------------------------------------------------------ */
-
-knh_bool_t
-knh_NameSpace_isLoaded(Ctx *ctx, NameSpace *o, knh_fileid_t fileid)
-{
-	if(IS_NOTNULL(DP(o)->lconstDictMap)) {
-		char buf[80];
-		knh_snprintf(buf, sizeof(buf), "_LOADED_%d", (int)fileid);
-		return (knh_DictMap_index__b(DP(o)->lconstDictMap, B(buf)) != -1);
-	}
-	return 0;
-}
 
 /* ------------------------------------------------------------------------ */
 
