@@ -79,50 +79,41 @@ Object *new_Nue(Ctx *ctx, String *msg)
 #define _new_Nue__b(ctx, txt)   new_Nue(ctx, new_String(ctx, txt, NULL));
 #define _new_Nue__s(ctx, txt)   new_Nue(ctx, new_String(ctx, B(txt), NULL));
 
+/* ======================================================================== */
+/* [Glue] */
+
+static
+void knh_fgfree__default(Ctx *ctx, knh_Glue_t *g, knh_ftraverse ftr)
+{
+	if(IS_SWEEP(ftr)) {
+		g->ptr = NULL;
+	}
+}
+
 /* ------------------------------------------------------------------------ */
 
+KNHAPI(void) knh_Glue_init(Ctx *ctx, knh_Glue_t *g, void *ptr, knh_fgfree gfree)
+{
+	DBG_P("bcid=%s, cid=%s", CLASSN(g->h.bcid), CLASSN(g->h.cid));
+	KNH_ASSERT(IS_bAny(g));
+	g->ptr = ptr;
+	if(gfree == NULL) gfree = knh_fgfree__default;
+	g->gfree = gfree;
+}
 
+/* ------------------------------------------------------------------------ */
 
-///* ======================================================================== */
-///* [COBJ] */
-//
-//static
-//void knh_fcfree__default(Ctx *ctx, void *ptr, knh_ftraverse ftr)
-//{
-//	;
-//}
-//
-///* ------------------------------------------------------------------------ */
-//
-//static
-//Object *knh_fccopy__default(Ctx *ctx, knh_Glue_t *ptr)
-//{
-//	TODO();
-//	return (Object*)ptr;
-//}
-//
-///* ------------------------------------------------------------------------ */
-//
-//KNHAPI(void) knh_COBJ_init(Ctx *ctx, Object *o, void *ptr, knh_fgluefree cf, knh_fccopy cc)
-//{
-//	KNH_ASSERT(IS_bAny(o));
-//	knh_Glue_t *c = (knh_Glue_t*)o;
-//	if(ptr != NULL) {
-//		c->cptr = ptr;
-//		if(cf == NULL) cf = knh_fcfree__default;
-//		c->cfree = cf;
-//		if(cc == NULL) cc = knh_fccopy__default;
-//		c->ccopy = cc;
-//	}
-//	else {
-//		if(c->cptr != NULL) {
-//			c->cfree(ctx, c->cptr, knh_Object_sweep);
-//		}
-//		c->cptr = NULL;
-//		c->cfree = knh_fcfree__default;
-//		c->ccopy = knh_fccopy__default;
-//	}
-//}
+KNHAPI(Object*) new_Glue(Ctx *ctx, char *lname, void *ptr, knh_fgfree gfree)
+{
+	knh_class_t cid = konoha_getcid(ctx, lname);
+	if(cid == CLASS_unknown) {
+		KNH_THROWf(ctx, "Unknown!!: %s", lname);
+	}
+	knh_Glue_t *g = (knh_Glue_t*)new_Object_bcid(ctx, CLASS_Any, 0);
+	g->h.cid = cid;
+	knh_Glue_init(ctx, g, ptr, gfree);
+	return (Object*)g;
+}
 
 /* ======================================================================== */
 /* [new] */
