@@ -256,6 +256,28 @@ KNHAPI(knh_bytes_t) knh_StringNULL_tobytes(String *o, knh_bytes_t def)
 
 /* ------------------------------------------------------------------------ */
 
+knh_bool_t knh_String_equals(String *o, knh_bytes_t s)
+{
+//	knh_bytes_t t = knh_String_tobytes(o);
+	return (o->size == s.len && knh_strncmp((char*)o->str, (char*)s.buf, s.len) == 0);
+}
+
+/* ------------------------------------------------------------------------ */
+
+knh_bool_t knh_String_startsWith(String *b, knh_bytes_t s)
+{
+	return knh_bytes_startsWith(knh_String_tobytes(b), s);
+}
+
+/* ------------------------------------------------------------------------ */
+
+knh_bool_t knh_String_endsWith(String *b, knh_bytes_t s)
+{
+	return knh_bytes_endsWith(knh_String_tobytes(b), s);
+}
+
+/* ------------------------------------------------------------------------ */
+
 
 #ifdef __cplusplus
 }
