@@ -69,7 +69,6 @@ knh_methodn_t knh_Token_getmn(Ctx *ctx, Token *o)
 		return DP(o)->mn;
 	}
 	else if(SP(o)->tt == TT_FN) {
-		DBG2_ABORT();
 		knh_methodn_t mn = FIELDN_UNMASK(DP(o)->fn);
 		if(knh_Token_isGetter(o)) {
 			return mn | KNH_FLAG_MN_GETTER;
@@ -103,8 +102,9 @@ knh_methodn_t knh_Token_getmn(Ctx *ctx, Token *o)
 		return knh_tName_getMethodn(ctx, name, METHODN_NEWID) | KNH_FLAG_MN_MOVTEXT;
 	}
 	DBG2_P("SP(o)->tt=%s, '%s'", knh_token_tochar(SP(o)->tt), (char*)name.buf);
-	DBG2_ABORT();
-	return knh_tName_getMethodn(ctx, name, METHODN_NEWID);
+	TODO();
+	return METHODN_NONAME;
+	//return knh_tName_getMethodn(ctx, name, METHODN_NEWID);
 }
 
 /* ======================================================================== */
@@ -313,7 +313,7 @@ int knh_Token_toSYSVAL(Ctx *ctx, Token *tk, Asm *abr)
 		return 1;
 	}
 	else if(IS_SYSVAL(t, "__file__")) {
-		knh_Token_setCONST(ctx, tk, UP(knh_tfileid_name(ctx, SP(tk)->fileid)));
+		knh_Token_setCONST(ctx, tk, UP(konoha_getFileName(ctx, SP(tk)->fileid)));
 		return 1;
 	}
 	else if(IS_SYSVAL(t, "__method__") || IS_SYSVAL(t, "__function__")) {
@@ -564,8 +564,8 @@ int knh_TokenCONSTN_typing(Ctx *ctx, Token *o, Asm *abr, NameSpace *ns)
 			char buf[CLASSNAME_BUFSIZ*2];
 			knh_snprintf(buf, sizeof(buf), "%s.%s", CLASSN(cid), &t.buf[loc+1]);
 			t = B(buf);
-			if(knh_tConst_exists(ctx, t)) {
-				knh_Token_setCONST(ctx, o, knh_tConst_value(ctx, t));
+			if(konoha_existsConst(ctx, t)) {
+				knh_Token_setCONST(ctx, o, konoha_getConst(ctx, t));
 				return 1;
 			}
 		}
@@ -1231,6 +1231,22 @@ int TERMs_isCONSTNAME(Ctx *ctx, Stmt *stmt, size_t n, Asm *abr, NameSpace *ns)
 
 /* ------------------------------------------------------------------------ */
 
+static
+int konoha_addClassConst(Ctx *ctx, knh_class_t cid, knh_bytes_t name, Object *value)
+{
+	KNH_ASSERT_cid(cid);
+	char bufcn[CLASSNAME_BUFSIZ];
+	knh_snprintf(bufcn, sizeof(bufcn), "%s.%s", CLASSN(cid), (char*)name.buf);
+	name = B(bufcn);
+	if(konoha_existsConst(ctx, name)) {
+		return 0;
+	}
+	konoha_addConst(ctx, new_String(ctx, name, NULL), value);
+	return 1;
+}
+
+/* ------------------------------------------------------------------------ */
+
 static
 Term *knh_StmtLET_declCONST(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, int level)
 {
@@ -1266,7 +1282,7 @@ Term *knh_StmtLET_declCONST(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, int l
 			if(cid == CLASS_unknown) {
 				pe = KMSG_UCLASSN; goto L_PERROR;
 			}
-			if(!knh_tConst_addClassConst(ctx, cid, knh_bytes_last(cn, dotidx+1), value)) {
+			if(!konoha_addClassConst(ctx, cid, knh_bytes_last(cn, dotidx+1), value)) {
 				pe = KMSG_DUPCONST; goto L_PERROR;
 			}
 		}
@@ -1276,7 +1292,7 @@ Term *knh_StmtLET_declCONST(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, int l
 		if(dotidx != -1) {
 			pe = KMSG_NOTHERE; goto L_PERROR;
 		}
-		if(!knh_tConst_addClassConst(ctx, cid, knh_bytes_last(cn, dotidx+1), value)) {
+		if(!konoha_addClassConst(ctx, cid, knh_bytes_last(cn, dotidx+1), value)) {
 			pe = KMSG_DUPCONST; goto L_PERROR;
 		}
 	}
@@ -3055,6 +3071,48 @@ int knh_Stmt_checkLastReturn(Ctx *ctx, Stmt *stmt, Method *mtd)
 
 /* ------------------------------------------------------------------------ */
 
+static
+char *knh_format_funcname(Ctx *ctx, char *buf, size_t bufsiz, knh_class_t cid, knh_methodn_t mn)
+{
+	KNH_ASSERT_cid(cid);
+	char *cname = knh_String_tochar(ctx->tClass[cid].sname);
+	if(METHODN_IS_MOVTEXT(mn)) {
+		knh_snprintf(buf, bufsiz, "%s__%s", cname, FIELDN(METHODN_TOFIELDN(mn)));
+		return buf;
+	}
+	if(METHODN_IS_GETTER(mn)) {
+		int off = knh_strlen(cname)+4;
+		knh_snprintf(buf, bufsiz, "%s_get%s", cname, FIELDN(METHODN_TOFIELDN(mn)));
+		if(islower(buf[off])) buf[off] = toupper(buf[off]);
+		return buf;
+	}
+	if(METHODN_IS_SETTER(mn)) {
+		int off = knh_strlen(cname)+4;
+		knh_snprintf(buf, bufsiz, "%s_set%s", cname, FIELDN(METHODN_TOFIELDN(mn)));
+		if(islower(buf[off])) buf[off] = toupper(buf[off]);
+		return buf;
+	}
+	knh_snprintf(buf, bufsiz, "%s_%s", cname, FIELDN(mn));
+	return buf;
+}
+
+/* ------------------------------------------------------------------------ */
+
+static
+knh_fmethod knh_Asm_loadMethodFunc(Ctx *ctx, Asm *abr, knh_class_t cid, knh_methodn_t mn)
+{
+	if(DP(abr)->dlhdr != NULL) {
+		char buf[80];
+		knh_format_funcname(ctx, buf, sizeof(buf), cid, mn);
+		void *f = knh_dlsym(ctx, DP(abr)->dlhdr, buf);
+		if(f != NULL) return (knh_fmethod)f;
+		DBG2_P("Function not found: %s", buf);
+	}
+	return NULL;
+}
+
+/* ------------------------------------------------------------------------ */
+
 Term * knh_StmtMETHOD_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 {
 	int level = DP(abr)->level;
@@ -3155,6 +3213,13 @@ Term * knh_StmtMETHOD_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		else {
 			knh_Stmt_checkLastReturn(ctx, StmtMETHOD_instmt(stmt), mtd);
 		}
+	}
+	{
+		knh_fmethod func = knh_Asm_loadMethodFunc(ctx, abr, mtd_cid, DP(mtd)->mn);
+		if(func != NULL) {
+			knh_Method_syncfunc(mtd, func);
+			knh_Stmt_done(ctx, stmt);
+		}
 		return TM(stmt);
 	}
 
