@@ -1,7 +1,7 @@
 /****************************************************************************
  * KONOHA COPYRIGHT, LICENSE NOTICE, AND DISCRIMER  
  * 
- * Copyright (c) 2005-2008, Kimio Kuramitsu <kimio at ynu.ac.jp>
+ * Copyright (c) 2005-2009, Kimio Kuramitsu <kimio at ynu.ac.jp>
  *           (c) 2008-      Konoha Software Foundation  
  * All rights reserved.
  * 
@@ -404,19 +404,6 @@ METHOD knh__Array_clear(Ctx *ctx, knh_sfp_t *sfp)
 	KNH_RETURN(ctx, sfp, KNH_VOID);
 }
 
-static
-METHOD knh__Object_compareTo(Ctx *ctx, knh_sfp_t *sfp)
-{
-	/* method Int! Object.compareTo(Any o)  */
-	int v = knh_Object_compareTo(
-		ctx,
-		(knh_Object_t*)sfp[0].o,
-		(Object*)sfp[1].o /* Any sfp[1].o => Object* o2 */
-	);
-	Object* rv = (Object*)new_Int(ctx, (knh_int_t)v) /* int v => Int rv */;
-	KNH_RETURN(ctx, sfp, rv);
-}
-
 static
 METHOD knh__InputStream_setEncoding(Ctx *ctx, knh_sfp_t *sfp)
 {
@@ -441,42 +428,6 @@ METHOD knh__OutputStream_setEncoding(Ctx *ctx, knh_sfp_t *sfp)
 	KNH_RETURN(ctx, sfp, KNH_VOID);
 }
 
-static
-METHOD knh__String_equals(Ctx *ctx, knh_sfp_t *sfp)
-{
-	/* method Boolean! String.equals(String! s)  */
-	knh_bool_t v = knh_String_equals(
-		(knh_String_t*)sfp[0].o,
-		knh_String_tobytes((String*)sfp[1].o) /* String! sfp[1].o => knh_bytes_t s */
-	);
-	Object* rv = (Object*)new_Boolean(ctx, v) /* knh_bool_t v => Boolean rv */;
-	KNH_RETURN(ctx, sfp, rv);
-}
-
-static
-METHOD knh__String_startsWith(Ctx *ctx, knh_sfp_t *sfp)
-{
-	/* method Boolean! String.startsWith(String! s)  */
-	knh_bool_t v = knh_String_startsWith(
-		(knh_String_t*)sfp[0].o,
-		knh_String_tobytes((String*)sfp[1].o) /* String! sfp[1].o => knh_bytes_t s */
-	);
-	Object* rv = (Object*)new_Boolean(ctx, v) /* knh_bool_t v => Boolean rv */;
-	KNH_RETURN(ctx, sfp, rv);
-}
-
-static
-METHOD knh__String_endsWith(Ctx *ctx, knh_sfp_t *sfp)
-{
-	/* method Boolean! String.endsWith(String! s)  */
-	knh_bool_t v = knh_String_endsWith(
-		(knh_String_t*)sfp[0].o,
-		knh_String_tobytes((String*)sfp[1].o) /* String! sfp[1].o => knh_bytes_t s */
-	);
-	Object* rv = (Object*)new_Boolean(ctx, v) /* knh_bool_t v => Boolean rv */;
-	KNH_RETURN(ctx, sfp, rv);
-}
-
 static
 METHOD knh__Context_getProperty(Ctx *ctx, knh_sfp_t *sfp)
 {
