@@ -102,7 +102,14 @@ KNHAPI(Ctx*) konoha_getCurrentContext(void)
 /* ======================================================================== */
 /* [option] */
 
-static int debugMode2 = 0;
+static int debugMode = 0;
+
+/* ----------------------------------------------------------------------- */
+
+KNHAPI(int) konoha_isDebugMode()
+{
+	return debugMode;
+}
 
 /* ----------------------------------------------------------------------- */
 
@@ -136,7 +143,7 @@ KNHAPI(int) konoha_parseopt(konoha_t konoha, int argc, char **argv)
 			knh_Context_setCompiling(konoha.ctx, 1);
 		}
 		if(t[1] == 'd' && t[2] == '2' && t[3] == 0) {
-			debugMode2 = 1;
+			debugMode = 1;
 			konoha_checksize();
 		}
 	}
@@ -160,7 +167,7 @@ KNHAPI(char*) konoha_eval(konoha_t konoha, char *script)
 		knh_Bytes_putc(ctx, cwb.ba, '\n');
 		InputStream *in = new_BytesInputStream(ctx, cwb.ba, cwb.pos, knh_Bytes_size(cwb.ba));
 		KNH_LPUSH(ctx, in);
-		DP(in)->fileid = knh_tName_getFileId(ctx, STEXT("(eval)"));
+		DP(in)->fileid = konoha_getFileId(ctx, STEXT("(eval)"));
 		DP(in)->line = 0;
 
 		ba = new_Bytes(ctx, 1024);
@@ -190,7 +197,7 @@ KNHAPI(void) konoha_readFile(Ctx *ctx, char *fpath)
 	if(knh_InputStream_isClosed(in)) {
 		KNH_WARNING(ctx, "No such script file: %s\n", fpath);
 	}
-	DP(in)->fileid = knh_tName_getFileId(ctx, B(fpath));
+	DP(in)->fileid = konoha_getFileId(ctx, B(fpath));
 	knh_InputStream_setEncoding(ctx, in, knh_systemEncoding);
 	konohac_eval(ctx, (String*)KNH_NULL, in);
 	knh_Context_clearstack(ctx);
@@ -219,7 +226,7 @@ KNHAPI(int) konoha_main(konoha_t konoha, int argc, char **argv)
 	KNH_MOV(ctx, lsfp[0].o, new_ExceptionHandler(ctx));
 	KNH_TRY(ctx, L_CATCH, lsfp, 0);
 	{
-		NameSpace *ns = knh_Runtime_getNameSpace(ctx, STEXT("main"));
+		NameSpace *ns = knh_System_getNameSpace(ctx, STEXT("main"));
 		Script *scr = knh_NameSpace_getScript(ctx, ns);
 		Method *mtd = knh_Class_getMethod(ctx, knh_Object_cid(scr), METHODN_main);
 
@@ -421,7 +428,7 @@ KNHAPI(void) konoha_shell(konoha_t konoha)
 			{
 				InputStream *in = new_BytesInputStream(ctx, cwb.ba, cwb.pos, knh_Bytes_size(cwb.ba));
 				KNH_MOV(ctx, lsfp[0].o, in);
-				DP(in)->fileid = knh_tName_getFileId(ctx, STEXT("(shell)"));
+				DP(in)->fileid = konoha_getFileId(ctx, STEXT("(shell)"));
 				DP(in)->line = linenum;
 				knh_InputStream_setEncoding(ctx, in, knh_systemEncoding);
 				konohac_eval(ctx, TS_main, in);
@@ -446,10 +453,10 @@ METHOD knh__Script_eval(Ctx *ctx, knh_sfp_t *sfp)
 		InputStream *in = new_BytesInputStream(ctx, cwb.ba, cwb.pos, knh_Bytes_size(cwb.ba));
 		KNH_LPUSH(ctx, in);
 		if(IS_NULL(sfp[2].o)) {
-			DP(in)->fileid = knh_tName_getFileId(ctx, STEXT("(eval)"));
+			DP(in)->fileid = konoha_getFileId(ctx, STEXT("(eval)"));
 		}
 		else {
-			DP(in)->fileid = knh_tName_getFileId(ctx, knh_String_tobytes(sfp[2].s));
+			DP(in)->fileid = konoha_getFileId(ctx, knh_String_tobytes(sfp[2].s));
 		}
 		if(IS_NULL(sfp[3].o)) {
 			DP(in)->line = 0;
