@@ -136,21 +136,6 @@ typedef struct {
 	knh_class_t tcid;
 } knh_MapperData_t ;
 
-typedef struct {
-	char *name;
-	knh_integer_t ivalue;
-} knh_IntConstData_t;
-
-typedef struct {
-	char *name;
-	knh_float_t fvalue;
-} knh_FloatConstData_t;
-
-typedef struct {
-	char *name;
-	char *value;
-} knh_StringConstData_t;
-
 /* ======================================================================== */
 /* Object */
 
@@ -232,18 +217,10 @@ void knh_ObjectField_traverse(Ctx *ctx, knh_ObjectField_t *of, knh_ftraverse ftr
 
 /* ------------------------------------------------------------------------ */
 
-static
-void knh_fgluecopy_NOP(Ctx *ctx, void *ptr, knh_ftraverse ftr)
-{
-}
-
-/* ------------------------------------------------------------------------ */
-
 static
 void knh_Any_init(Ctx *ctx, knh_Glue_t *g, int init)
 {
-	g->ptr = NULL;
-	g->gluefree = knh_fgluecopy_NOP;
+	knh_Glue_init(ctx, g, NULL, NULL);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -251,9 +228,7 @@ void knh_Any_init(Ctx *ctx, knh_Glue_t *g, int init)
 static
 void knh_Any_traverse(Ctx *ctx, knh_Glue_t *g, knh_ftraverse ftr)
 {
-	g->gluefree(ctx, g->ptr, ftr);
-	g->ptr = NULL;
-	g->gluefree = knh_fgluecopy_NOP;
+	g->gfree(ctx, g, ftr);
 }
 
 /* ======================================================================== */
@@ -1815,8 +1790,8 @@ void knh_NameSpace_init(Ctx *ctx, NameSpace *ns, int init)
 	KNH_INITv(b->name2cidDictSet, KNH_NULL);
 	KNH_INITv(b->tag2urnDictMap, KNH_NULL);
 	KNH_INITv(b->func2cidDictSet, KNH_NULL);
-	b->dlhdr = NULL;
-	b->pkgmeta = NULL;
+//	b->dlhdr = NULL;
+//	b->pkgmeta = NULL;
 }
 
 /* ------------------------------------------------------------------------ */
@@ -1833,15 +1808,15 @@ void knh_NameSpace_traverse(Ctx *ctx, NameSpace *ns, knh_ftraverse ftr)
 	ftr(ctx, UP(b->name2cidDictSet));
 	ftr(ctx, UP(b->tag2urnDictMap));
 	ftr(ctx, UP(b->func2cidDictSet));
-	if(b->pkgmeta != NULL && b->pkgmeta->ftraverse != NULL) {
-		b->pkgmeta->ftraverse(ctx, ftr);
-	}
-	if(IS_SWEEP(ftr)) {
-		if(b->dlhdr != NULL) {
-			knh_dlclose(ctx, b->dlhdr);
-			b->dlhdr = NULL;
-		}
-	}
+//	if(b->pkgmeta != NULL && b->pkgmeta->ftraverse != NULL) {
+//		b->pkgmeta->ftraverse(ctx, ftr);
+//	}
+//	if(IS_SWEEP(ftr)) {
+//		if(b->dlhdr != NULL) {
+//			knh_dlclose(ctx, b->dlhdr);
+//			b->dlhdr = NULL;
+//		}
+//	}
 }
 
 /* ======================================================================== */
@@ -1895,9 +1870,7 @@ void knh_System_init(Ctx *ctx, System *o, int init)
 	KNH_INITv(sys->turnAliasDictMap, new_DictMap0(ctx, 8));
 
 	knh_DictMap_set(ctx, sys->props, new_String__T(ctx, "konoha.encoding"), UP(sys->enc));
-	knh_DictMap_set(ctx, sys->props, new_String__T(ctx, "konoha.path.home"), UP(sys->homeDir));
-	knh_DictMap_set(ctx, sys->props, new_String__T(ctx, "konoha.path.package"),
-			UP(new_String(ctx, B(knh_format_packagedir(buf, sizeof(buf),knh_String_tochar(sys->homeDir))), NULL)));
+	knh_DictMap_set(ctx, sys->props, new_String__T(ctx, "konoha.home"), UP(sys->homeDir));
 	knh_DictMap_set(ctx, sys->props, new_String__T(ctx, "konoha.lang"),
 			UP(new_String(ctx, B(knh_format_lang(buf, sizeof(buf))), NULL)));
 	knh_Asm_setLang(buf);
@@ -2074,7 +2047,7 @@ void knh_Asm_init(Ctx *ctx, Asm *abr, int init)
 	b->flag = 0;
 	b->this_cid = CLASS_Object;
 
-	KNH_INITv(b->ns, knh_Runtime_getNameSpace(ctx, STEXT("main")));
+	KNH_INITv(b->ns, knh_System_getNameSpace(ctx, STEXT("main")));
 	KNH_INITv(b->mtd,   KNH_NULL);
 	b->level = 0;
 
@@ -2106,6 +2079,7 @@ void knh_Asm_init(Ctx *ctx, Asm *abr, int init)
 	KNH_INITv(b->elf, new_Bytes(ctx, 4096));
 	KNH_INITv(b->dwarf, new_Bytes(ctx, 1024));
 
+	b->dlhdr = NULL;
 	KNH_INITv(b->constPools, KNH_NULL);
 	KNH_INITv(b->exportsMethods, KNH_NULL);
 }
@@ -2139,6 +2113,10 @@ void knh_Asm_traverse(Ctx *ctx, Asm *abr, knh_ftraverse ftr)
 	ftr(ctx, UP(b->lstacks));
 	ftr(ctx, UP(b->finallyStmt));
 
+	if(IS_SWEEP(ftr) && b->dlhdr != NULL) {
+		//knh_dlclose(ctx, b->dlhdr);
+		b->dlhdr = NULL;
+	}
 	ftr(ctx, UP(b->exportsMethods));
 	ftr(ctx, UP(b->constPools));
 }
@@ -2670,42 +2648,6 @@ void konoha_loadMapperData(Ctx *ctx, knh_MapperData_t *data)
 
 /* ------------------------------------------------------------------------ */
 
-static void konoha_loadIntConstData(Ctx *ctx, knh_IntConstData_t *data)
-{
-	DictMap *tcmap = DP(ctx->sys)->tConstDictMap;
-	while(data->name != NULL) {
-		String *n = new_String__T(ctx, data->name);
-		knh_DictMap_append(ctx, tcmap, n, UP(new_Int(ctx, data->ivalue)));
-		data++;
-	}
-}
-
-/* ------------------------------------------------------------------------ */
-
-static void konoha_loadFloatConstData(Ctx *ctx, knh_FloatConstData_t *data)
-{
-	DictMap *tcmap = DP(ctx->sys)->tConstDictMap;
-	while(data->name != NULL) {
-		String *n = new_String__T(ctx, data->name);
-		knh_DictMap_append(ctx, tcmap, n, UP(new_Float(ctx, data->fvalue)));
-		data++;
-	}
-}
-
-/* ------------------------------------------------------------------------ */
-
-static void konoha_loadStringConstData(Ctx *ctx, knh_StringConstData_t *data)
-{
-	DictMap *tcmap = DP(ctx->sys)->tConstDictMap;
-	while(data->name != NULL) {
-		String *n = new_String__T(ctx, data->name);
-		knh_DictMap_append(ctx, tcmap, n, UP(new_String__T(ctx, data->value)));
-		data++;
-	}
-}
-
-/* ------------------------------------------------------------------------ */
-
 static void konoha_loadStringPropertyData(Ctx *ctx, knh_StringConstData_t *data)
 {
 	DictMap *pmap = DP(ctx->sys)->props;
