@@ -148,7 +148,7 @@ void konoha_initContext(Ctx *ctx, knh_Context_t *o, size_t stacksize)
 			o->stack[i].data = 0;
 		}
 	}
-	o->doing = NULL;
+	o->cwd = NULL;
 
 	KNH_INITv(o->bufa, new_Bytes(ctx, o->stacksize * 4));
 	KNH_INITv(o->bufw, new_BytesOutputStream(ctx, o->bufa));
